# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../ui/peakpo.ui'
#
# Created by: PyQt6 UI code generator
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.

import os
from qtpy import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1401, 891)
        MainWindow.setMinimumSize(QtCore.QSize(0, 750))
        MainWindow.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        MainWindow.setFont(font)
        if os.name == 'nt':
            mpl_fontsize = 9
        else:
            mpl_fontsize = 12
        # Use QFont instead of a global stylesheet font rule.
        # Qt6 can clip glyph ascent when font is forced via stylesheet.
        font.setPointSize(mpl_fontsize)
        MainWindow.setFont(font)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitter.sizePolicy().hasHeightForWidth())
        self.splitter.setSizePolicy(sizePolicy)
        self.splitter.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.splitter.setLineWidth(0)
        self.splitter.setMidLineWidth(0)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setOpaqueResize(True)
        self.splitter.setHandleWidth(7)
        self.splitter.setChildrenCollapsible(True)
        self.splitter.setObjectName("splitter")
        self.mpl = MplWidget(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.mpl.sizePolicy().hasHeightForWidth())
        self.mpl.setSizePolicy(sizePolicy)
        self.mpl.setMinimumSize(QtCore.QSize(700, 0))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(mpl_fontsize)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.mpl.setFont(font)
        self.mpl.setObjectName("mpl")
        self.frame_5 = QtWidgets.QFrame(self.splitter)
        self.frame_5.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_5.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame_5.setLineWidth(0)
        self.frame_5.setObjectName("frame_5")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.frame_5)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.frame_9 = QtWidgets.QFrame(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_9.sizePolicy().hasHeightForWidth())
        self.frame_9.setSizePolicy(sizePolicy)
        self.frame_9.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_9.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame_9.setLineWidth(0)
        self.frame_9.setObjectName("frame_9")
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout(self.frame_9)
        self.horizontalLayout_21.setContentsMargins(1, 1, 1, 1)
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        self.pushButton_S_Zoom = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_Zoom.sizePolicy().hasHeightForWidth())
        self.pushButton_S_Zoom.setSizePolicy(sizePolicy)
        self.pushButton_S_Zoom.setMinimumSize(QtCore.QSize(40, 25))
        self.pushButton_S_Zoom.setMaximumSize(QtCore.QSize(25, 16777215))
        self.pushButton_S_Zoom.setObjectName("pushButton_S_Zoom")
        self.horizontalLayout_21.addWidget(self.pushButton_S_Zoom)
        self.pushButton_S_SaveSession = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_SaveSession.sizePolicy().hasHeightForWidth())
        self.pushButton_S_SaveSession.setSizePolicy(sizePolicy)
        self.pushButton_S_SaveSession.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_SaveSession.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_SaveSession.setObjectName("pushButton_S_SaveSession")
        self.horizontalLayout_21.addWidget(self.pushButton_S_SaveSession)
        self.pushButton_S_PrevBasePtn = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_PrevBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_S_PrevBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_S_PrevBasePtn.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_PrevBasePtn.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_PrevBasePtn.setObjectName("pushButton_S_PrevBasePtn")
        self.horizontalLayout_21.addWidget(self.pushButton_S_PrevBasePtn)
        self.pushButton_AddBasePtn = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_AddBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_AddBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_AddBasePtn.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_AddBasePtn.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_AddBasePtn.setCheckable(True)
        self.pushButton_AddBasePtn.setObjectName("pushButton_AddBasePtn")
        self.horizontalLayout_21.addWidget(self.pushButton_AddBasePtn)
        self.pushButton_S_NextBasePtn = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_NextBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_S_NextBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_S_NextBasePtn.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_NextBasePtn.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_NextBasePtn.setObjectName("pushButton_S_NextBasePtn")
        self.horizontalLayout_21.addWidget(self.pushButton_S_NextBasePtn)
        self.pushButton_S_PIncrease = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_PIncrease.sizePolicy().hasHeightForWidth())
        self.pushButton_S_PIncrease.setSizePolicy(sizePolicy)
        self.pushButton_S_PIncrease.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_PIncrease.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_PIncrease.setObjectName("pushButton_S_PIncrease")
        self.horizontalLayout_21.addWidget(self.pushButton_S_PIncrease)
        self.pushButton_S_PDecrease = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_PDecrease.sizePolicy().hasHeightForWidth())
        self.pushButton_S_PDecrease.setSizePolicy(sizePolicy)
        self.pushButton_S_PDecrease.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_PDecrease.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_PDecrease.setObjectName("pushButton_S_PDecrease")
        self.horizontalLayout_21.addWidget(self.pushButton_S_PDecrease)
        self.pushButton_S_TIncrease = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_TIncrease.sizePolicy().hasHeightForWidth())
        self.pushButton_S_TIncrease.setSizePolicy(sizePolicy)
        self.pushButton_S_TIncrease.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_TIncrease.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_TIncrease.setIconSize(QtCore.QSize(16, 16))
        self.pushButton_S_TIncrease.setFlat(False)
        self.pushButton_S_TIncrease.setObjectName("pushButton_S_TIncrease")
        self.horizontalLayout_21.addWidget(self.pushButton_S_TIncrease)
        self.pushButton_S_RoomT = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_RoomT.sizePolicy().hasHeightForWidth())
        self.pushButton_S_RoomT.setSizePolicy(sizePolicy)
        self.pushButton_S_RoomT.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_RoomT.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_RoomT.setObjectName("pushButton_S_RoomT")
        self.horizontalLayout_21.addWidget(self.pushButton_S_RoomT)
        self.pushButton_S_TDecrease = QtWidgets.QPushButton(self.frame_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_S_TDecrease.sizePolicy().hasHeightForWidth())
        self.pushButton_S_TDecrease.setSizePolicy(sizePolicy)
        self.pushButton_S_TDecrease.setMinimumSize(QtCore.QSize(25, 25))
        self.pushButton_S_TDecrease.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_S_TDecrease.setBaseSize(QtCore.QSize(0, 0))
        self.pushButton_S_TDecrease.setObjectName("pushButton_S_TDecrease")
        self.horizontalLayout_21.addWidget(self.pushButton_S_TDecrease)
        self.verticalLayout_9.addWidget(self.frame_9)
        self.frame_2 = QtWidgets.QFrame(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_2.sizePolicy().hasHeightForWidth())
        self.frame_2.setSizePolicy(sizePolicy)
        self.frame_2.setMaximumSize(QtCore.QSize(16777215, 50))
        self.frame_2.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_2.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_2.setObjectName("frame_2")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.frame_2)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.pushButton_NewBasePtn = QtWidgets.QPushButton(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_NewBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_NewBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_NewBasePtn.setMinimumSize(QtCore.QSize(10, 25))
        self.pushButton_NewBasePtn.setMaximumSize(QtCore.QSize(100, 16777215))
        self.pushButton_NewBasePtn.setBaseSize(QtCore.QSize(200, 0))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_NewBasePtn.setFont(font)
        self.pushButton_NewBasePtn.setWhatsThis("")
        self.pushButton_NewBasePtn.setObjectName("pushButton_NewBasePtn")
        self.horizontalLayout_7.addWidget(self.pushButton_NewBasePtn)
        self.pushButton_LoadDPP = QtWidgets.QPushButton(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_LoadDPP.sizePolicy().hasHeightForWidth())
        self.pushButton_LoadDPP.setSizePolicy(sizePolicy)
        self.pushButton_LoadDPP.setMinimumSize(QtCore.QSize(10, 25))
        self.pushButton_LoadDPP.setMaximumSize(QtCore.QSize(100, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_LoadDPP.setFont(font)
        self.pushButton_LoadDPP.setObjectName("pushButton_LoadDPP")
        self.horizontalLayout_7.addWidget(self.pushButton_LoadDPP)
        self.checkBox_ShowCake = QtWidgets.QCheckBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowCake.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowCake.setSizePolicy(sizePolicy)
        self.checkBox_ShowCake.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_ShowCake.setObjectName("checkBox_ShowCake")
        self.horizontalLayout_7.addWidget(self.checkBox_ShowCake)
        self.checkBox_BgSub = QtWidgets.QCheckBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_BgSub.sizePolicy().hasHeightForWidth())
        self.checkBox_BgSub.setSizePolicy(sizePolicy)
        self.checkBox_BgSub.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_BgSub.setChecked(False)
        self.checkBox_BgSub.setObjectName("checkBox_BgSub")
        self.horizontalLayout_7.addWidget(self.checkBox_BgSub)
        self.checkBox_AutoY = QtWidgets.QCheckBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_AutoY.sizePolicy().hasHeightForWidth())
        self.checkBox_AutoY.setSizePolicy(sizePolicy)
        self.checkBox_AutoY.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_AutoY.setChecked(True)
        self.checkBox_AutoY.setObjectName("checkBox_AutoY")
        self.horizontalLayout_7.addWidget(self.checkBox_AutoY)
        self.checkBox_LongCursor = QtWidgets.QCheckBox(self.frame_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_LongCursor.sizePolicy().hasHeightForWidth())
        self.checkBox_LongCursor.setSizePolicy(sizePolicy)
        self.checkBox_LongCursor.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_LongCursor.setChecked(False)
        self.checkBox_LongCursor.setObjectName("checkBox_LongCursor")
        self.horizontalLayout_7.addWidget(self.checkBox_LongCursor)
        self.verticalLayout_9.addWidget(self.frame_2)
        self.tabWidget = QtWidgets.QTabWidget(self.frame_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(400, 0))
        self.tabWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.tabWidget.setBaseSize(QtCore.QSize(0, 200))
        self.tabWidget.setTabPosition(QtWidgets.QTabWidget.North)
        self.tabWidget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget.setIconSize(QtCore.QSize(20, 20))
        self.tabWidget.setUsesScrollButtons(False)
        self.tabWidget.setDocumentMode(False)
        self.tabWidget.setTabsClosable(False)
        self.tabWidget.setMovable(False)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_Main = QtWidgets.QWidget()
        self.tab_Main.setObjectName("tab_Main")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.tab_Main)
        self.verticalLayout_18.setContentsMargins(12, 12, 12, 12)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.tabWidget_3 = QtWidgets.QTabWidget(self.tab_Main)
        self.tabWidget_3.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.tabWidget_3.setObjectName("tabWidget_3")
        self.tabWidget_3Page1 = QtWidgets.QWidget()
        self.tabWidget_3Page1.setObjectName("tabWidget_3Page1")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.tabWidget_3Page1)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.scrollArea = QtWidgets.QScrollArea(self.tabWidget_3Page1)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 568, 637))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox_28 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_28.sizePolicy().hasHeightForWidth())
        self.groupBox_28.setSizePolicy(sizePolicy)
        self.groupBox_28.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_28.setFlat(False)
        self.groupBox_28.setObjectName("groupBox_28")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.groupBox_28)
        self.verticalLayout_26.setContentsMargins(12, 12, 12, 12)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.frame_24 = QtWidgets.QFrame(self.groupBox_28)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_24.sizePolicy().hasHeightForWidth())
        self.frame_24.setSizePolicy(sizePolicy)
        self.frame_24.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_24.setLineWidth(0)
        self.frame_24.setObjectName("frame_24")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.frame_24)
        self.horizontalLayout_2.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_FirstBasePtn = QtWidgets.QPushButton(self.frame_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_FirstBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_FirstBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_FirstBasePtn.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_FirstBasePtn.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_FirstBasePtn.setObjectName("pushButton_FirstBasePtn")
        self.horizontalLayout_2.addWidget(self.pushButton_FirstBasePtn)
        self.pushButton_PrevBasePtn = QtWidgets.QPushButton(self.frame_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_PrevBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_PrevBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_PrevBasePtn.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PrevBasePtn.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_PrevBasePtn.setObjectName("pushButton_PrevBasePtn")
        self.horizontalLayout_2.addWidget(self.pushButton_PrevBasePtn)
        self.pushButton_NextBasePtn = QtWidgets.QPushButton(self.frame_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_NextBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_NextBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_NextBasePtn.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_NextBasePtn.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_NextBasePtn.setObjectName("pushButton_NextBasePtn")
        self.horizontalLayout_2.addWidget(self.pushButton_NextBasePtn)
        self.pushButton_LastBasePtn = QtWidgets.QPushButton(self.frame_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_LastBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_LastBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_LastBasePtn.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_LastBasePtn.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_LastBasePtn.setObjectName("pushButton_LastBasePtn")
        self.horizontalLayout_2.addWidget(self.pushButton_LastBasePtn)
        self.verticalLayout_26.addWidget(self.frame_24)
        self.frame_6 = QtWidgets.QFrame(self.groupBox_28)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_6.sizePolicy().hasHeightForWidth())
        self.frame_6.setSizePolicy(sizePolicy)
        self.frame_6.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.frame_6.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_6.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_6.setLineWidth(0)
        self.frame_6.setObjectName("frame_6")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.frame_6)
        self.horizontalLayout_13.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_21 = QtWidgets.QLabel(self.frame_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_21.sizePolicy().hasHeightForWidth())
        self.label_21.setSizePolicy(sizePolicy)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_13.addWidget(self.label_21)
        self.spinBox_FileStep = QtWidgets.QSpinBox(self.frame_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_FileStep.sizePolicy().hasHeightForWidth())
        self.spinBox_FileStep.setSizePolicy(sizePolicy)
        self.spinBox_FileStep.setMinimumSize(QtCore.QSize(50, 25))
        self.spinBox_FileStep.setMaximumSize(QtCore.QSize(70, 16777215))
        self.spinBox_FileStep.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_FileStep.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.spinBox_FileStep.setMinimum(1)
        self.spinBox_FileStep.setMaximum(999)
        self.spinBox_FileStep.setProperty("value", 1)
        self.spinBox_FileStep.setObjectName("spinBox_FileStep")
        self.horizontalLayout_13.addWidget(self.spinBox_FileStep)
        self.frame_23 = QtWidgets.QFrame(self.frame_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_23.sizePolicy().hasHeightForWidth())
        self.frame_23.setSizePolicy(sizePolicy)
        self.frame_23.setMinimumSize(QtCore.QSize(0, 25))
        self.frame_23.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.frame_23.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_23.setObjectName("frame_23")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.frame_23)
        self.horizontalLayout_6.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.radioButton_SortbyNme = QtWidgets.QRadioButton(self.frame_23)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.radioButton_SortbyNme.sizePolicy().hasHeightForWidth())
        self.radioButton_SortbyNme.setSizePolicy(sizePolicy)
        self.radioButton_SortbyNme.setMinimumSize(QtCore.QSize(0, 25))
        self.radioButton_SortbyNme.setMaximumSize(QtCore.QSize(70, 16777215))
        self.radioButton_SortbyNme.setIconSize(QtCore.QSize(16, 16))
        self.radioButton_SortbyNme.setChecked(True)
        self.radioButton_SortbyNme.setObjectName("radioButton_SortbyNme")
        self.horizontalLayout_6.addWidget(self.radioButton_SortbyNme)
        self.radioButton_SortbyTime = QtWidgets.QRadioButton(self.frame_23)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.radioButton_SortbyTime.sizePolicy().hasHeightForWidth())
        self.radioButton_SortbyTime.setSizePolicy(sizePolicy)
        self.radioButton_SortbyTime.setMinimumSize(QtCore.QSize(0, 25))
        self.radioButton_SortbyTime.setMaximumSize(QtCore.QSize(70, 16777215))
        self.radioButton_SortbyTime.setObjectName("radioButton_SortbyTime")
        self.horizontalLayout_6.addWidget(self.radioButton_SortbyTime)
        self.horizontalLayout_13.addWidget(self.frame_23)
        self.verticalLayout_26.addWidget(self.frame_6)
        self.verticalLayout_2.addWidget(self.groupBox_28)
        self.groupBox_3 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_3.sizePolicy().hasHeightForWidth())
        self.groupBox_3.setSizePolicy(sizePolicy)
        self.groupBox_3.setFlat(False)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout.setContentsMargins(12, 12, 12, 12)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(self.groupBox_3)
        self.frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setLineWidth(0)
        self.frame.setObjectName("frame")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout_10.setContentsMargins(9, 9, 9, 9)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.lineEdit_DiffractionPatternFileName = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineEdit_DiffractionPatternFileName.sizePolicy().hasHeightForWidth())
        self.lineEdit_DiffractionPatternFileName.setSizePolicy(sizePolicy)
        self.lineEdit_DiffractionPatternFileName.setMinimumSize(QtCore.QSize(0, 25))
        self.lineEdit_DiffractionPatternFileName.setCursorPosition(0)
        self.lineEdit_DiffractionPatternFileName.setClearButtonEnabled(False)
        self.lineEdit_DiffractionPatternFileName.setObjectName("lineEdit_DiffractionPatternFileName")
        self.horizontalLayout_10.addWidget(self.lineEdit_DiffractionPatternFileName)
        self.pushButton_Info = QtWidgets.QPushButton(self.frame)
        self.pushButton_Info.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_Info.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_Info.setObjectName("pushButton_Info")
        self.horizontalLayout_10.addWidget(self.pushButton_Info)
        self.verticalLayout.addWidget(self.frame)
        self.frame_4 = QtWidgets.QFrame(self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_4.sizePolicy().hasHeightForWidth())
        self.frame_4.setSizePolicy(sizePolicy)
        self.frame_4.setMinimumSize(QtCore.QSize(0, 0))
        self.frame_4.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.frame_4.setBaseSize(QtCore.QSize(250, 0))
        self.frame_4.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_4.setLineWidth(0)
        self.frame_4.setObjectName("frame_4")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.frame_4)
        self.horizontalLayout_11.setContentsMargins(9, 9, 9, 9)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.doubleSpinBox_SetWavelength = QtWidgets.QDoubleSpinBox(self.frame_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_SetWavelength.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_SetWavelength.setSizePolicy(sizePolicy)
        self.doubleSpinBox_SetWavelength.setMinimumSize(QtCore.QSize(80, 25))
        self.doubleSpinBox_SetWavelength.setMaximumSize(QtCore.QSize(80, 16777215))
        self.doubleSpinBox_SetWavelength.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_SetWavelength.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.doubleSpinBox_SetWavelength.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_SetWavelength.setDecimals(2)
        self.doubleSpinBox_SetWavelength.setSingleStep(0.01)
        self.doubleSpinBox_SetWavelength.setProperty("value", 532.22)
        self.doubleSpinBox_SetWavelength.setObjectName("doubleSpinBox_SetWavelength")
        self.horizontalLayout_11.addWidget(self.doubleSpinBox_SetWavelength)
        self.label_XRayEnergy = QtWidgets.QLabel(self.frame_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_XRayEnergy.sizePolicy().hasHeightForWidth())
        self.label_XRayEnergy.setSizePolicy(sizePolicy)
        self.label_XRayEnergy.setMinimumSize(QtCore.QSize(0, 25))
        self.label_XRayEnergy.setObjectName("label_XRayEnergy")
        self.horizontalLayout_11.addWidget(self.label_XRayEnergy)
        self.pushButton_SetXEat30 = QtWidgets.QPushButton(self.frame_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetXEat30.sizePolicy().hasHeightForWidth())
        self.pushButton_SetXEat30.setSizePolicy(sizePolicy)
        self.pushButton_SetXEat30.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SetXEat30.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetXEat30.setObjectName("pushButton_SetXEat30")
        self.horizontalLayout_11.addWidget(self.pushButton_SetXEat30)
        self.pushButton_SetXEat37 = QtWidgets.QPushButton(self.frame_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetXEat37.sizePolicy().hasHeightForWidth())
        self.pushButton_SetXEat37.setSizePolicy(sizePolicy)
        self.pushButton_SetXEat37.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SetXEat37.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetXEat37.setObjectName("pushButton_SetXEat37")
        self.horizontalLayout_11.addWidget(self.pushButton_SetXEat37)
        self.pushButton_SetXEat42 = QtWidgets.QPushButton(self.frame_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetXEat42.sizePolicy().hasHeightForWidth())
        self.pushButton_SetXEat42.setSizePolicy(sizePolicy)
        self.pushButton_SetXEat42.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SetXEat42.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetXEat42.setObjectName("pushButton_SetXEat42")
        self.horizontalLayout_11.addWidget(self.pushButton_SetXEat42)
        self.verticalLayout.addWidget(self.frame_4)
        self.verticalLayout_2.addWidget(self.groupBox_3)
        self.groupBox_2 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setFlat(False)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_8.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.pushButton_SaveDPP = QtWidgets.QPushButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SaveDPP.sizePolicy().hasHeightForWidth())
        self.pushButton_SaveDPP.setSizePolicy(sizePolicy)
        self.pushButton_SaveDPP.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SaveDPP.setMaximumSize(QtCore.QSize(40, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_SaveDPP.setFont(font)
        self.pushButton_SaveDPP.setObjectName("pushButton_SaveDPP")
        self.gridLayout_8.addWidget(self.pushButton_SaveDPP, 1, 3, 1, 1)
        self.pushButton_OpenBackupInfo = QtWidgets.QPushButton(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_OpenBackupInfo.sizePolicy().hasHeightForWidth())
        self.pushButton_OpenBackupInfo.setSizePolicy(sizePolicy)
        self.pushButton_OpenBackupInfo.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_OpenBackupInfo.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_OpenBackupInfo.setObjectName("pushButton_OpenBackupInfo")
        self.gridLayout_8.addWidget(self.pushButton_OpenBackupInfo, 1, 4, 1, 1)
        self.textEdit_SessionFileName = QtWidgets.QTextEdit(self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textEdit_SessionFileName.sizePolicy().hasHeightForWidth())
        self.textEdit_SessionFileName.setSizePolicy(sizePolicy)
        self.textEdit_SessionFileName.setMinimumSize(QtCore.QSize(0, 25))
        self.textEdit_SessionFileName.setMaximumSize(QtCore.QSize(16777215, 35))
        self.textEdit_SessionFileName.setReadOnly(True)
        self.textEdit_SessionFileName.setObjectName("textEdit_SessionFileName")
        self.gridLayout_8.addWidget(self.textEdit_SessionFileName, 1, 2, 1, 1)
        self.groupBox_36 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_36.sizePolicy().hasHeightForWidth())
        self.groupBox_36.setSizePolicy(sizePolicy)
        self.groupBox_36.setFlat(False)
        self.groupBox_36.setObjectName("groupBox_36")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.groupBox_36)
        self.gridLayout_21.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.checkBox_IgnoreRawDataExistence = QtWidgets.QCheckBox(self.groupBox_36)
        self.checkBox_IgnoreRawDataExistence.setChecked(True)
        self.checkBox_IgnoreRawDataExistence.setObjectName("checkBox_IgnoreRawDataExistence")
        self.gridLayout_21.addWidget(self.checkBox_IgnoreRawDataExistence, 0, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.groupBox_36)
        self.verticalLayout_2.addWidget(self.groupBox_2)
        spacerItem = QtWidgets.QSpacerItem(20, 68, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout_29.addWidget(self.scrollArea)
        self.tabWidget_3.addTab(self.tabWidget_3Page1, "")
        self.tabWidget_3Page2 = QtWidgets.QWidget()
        self.tabWidget_3Page2.setObjectName("tabWidget_3Page2")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.tabWidget_3Page2)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.scrollArea_2 = QtWidgets.QScrollArea(self.tabWidget_3Page2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollArea_2.sizePolicy().hasHeightForWidth())
        self.scrollArea_2.setSizePolicy(sizePolicy)
        self.scrollArea_2.setMinimumSize(QtCore.QSize(0, 0))
        self.scrollArea_2.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAsNeeded)
        self.scrollArea_2.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustIgnored)
        self.scrollArea_2.setWidgetResizable(True)
        self.scrollArea_2.setAlignment(QtCore.Qt.AlignCenter)
        self.scrollArea_2.setObjectName("scrollArea_2")
        self.scrollAreaWidgetContents_2 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_2.setGeometry(QtCore.QRect(0, 0, 375, 733))
        self.scrollAreaWidgetContents_2.setObjectName("scrollAreaWidgetContents_2")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_2)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.frame_10 = QtWidgets.QFrame(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_10.sizePolicy().hasHeightForWidth())
        self.frame_10.setSizePolicy(sizePolicy)
        self.frame_10.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_10.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame_10.setLineWidth(0)
        self.frame_10.setObjectName("frame_10")
        self.horizontalLayout_22 = QtWidgets.QHBoxLayout(self.frame_10)
        self.horizontalLayout_22.setContentsMargins(-1, 12, -1, 12)
        self.horizontalLayout_22.setObjectName("horizontalLayout_22")
        self.pushButton_AboutPeakpo = QtWidgets.QPushButton(self.frame_10)
        self.pushButton_AboutPeakpo.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_AboutPeakpo.setObjectName("pushButton_AboutPeakpo")
        self.horizontalLayout_22.addWidget(self.pushButton_AboutPeakpo)
        self.pushButton_Help = QtWidgets.QPushButton(self.frame_10)
        self.pushButton_Help.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_Help.setObjectName("pushButton_Help")
        self.horizontalLayout_22.addWidget(self.pushButton_Help)
        self.verticalLayout_31.addWidget(self.frame_10)
        self.groupBox_34 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_34.sizePolicy().hasHeightForWidth())
        self.groupBox_34.setSizePolicy(sizePolicy)
        self.groupBox_34.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_34.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_34.setFlat(False)
        self.groupBox_34.setObjectName("groupBox_34")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.groupBox_34)
        self.gridLayout_11.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_11.setVerticalSpacing(12)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.checkBox_JCPDSinCake = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_JCPDSinCake.sizePolicy().hasHeightForWidth())
        self.checkBox_JCPDSinCake.setSizePolicy(sizePolicy)
        self.checkBox_JCPDSinCake.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_JCPDSinCake.setChecked(True)
        self.checkBox_JCPDSinCake.setObjectName("checkBox_JCPDSinCake")
        self.gridLayout_11.addWidget(self.checkBox_JCPDSinCake, 1, 1, 1, 1)
        self.checkBox_Intensity = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_Intensity.sizePolicy().hasHeightForWidth())
        self.checkBox_Intensity.setSizePolicy(sizePolicy)
        self.checkBox_Intensity.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_Intensity.setChecked(True)
        self.checkBox_Intensity.setObjectName("checkBox_Intensity")
        self.gridLayout_11.addWidget(self.checkBox_Intensity, 2, 1, 1, 1)
        self.checkBox_JCPDSinPattern = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_JCPDSinPattern.sizePolicy().hasHeightForWidth())
        self.checkBox_JCPDSinPattern.setSizePolicy(sizePolicy)
        self.checkBox_JCPDSinPattern.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_JCPDSinPattern.setChecked(True)
        self.checkBox_JCPDSinPattern.setObjectName("checkBox_JCPDSinPattern")
        self.gridLayout_11.addWidget(self.checkBox_JCPDSinPattern, 0, 1, 1, 1)
        self.checkBox_ShowMillerIndices_Cake = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowMillerIndices_Cake.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowMillerIndices_Cake.setSizePolicy(sizePolicy)
        self.checkBox_ShowMillerIndices_Cake.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowMillerIndices_Cake.setObjectName("checkBox_ShowMillerIndices_Cake")
        self.gridLayout_11.addWidget(self.checkBox_ShowMillerIndices_Cake, 1, 2, 1, 1)
        self.checkBox_ShowMillerIndices = QtWidgets.QCheckBox(self.groupBox_34)
        self.checkBox_ShowMillerIndices.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowMillerIndices.setObjectName("checkBox_ShowMillerIndices")
        self.gridLayout_11.addWidget(self.checkBox_ShowMillerIndices, 0, 2, 1, 1)
        self.checkBox_ShowCakeLabels = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowCakeLabels.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowCakeLabels.setSizePolicy(sizePolicy)
        self.checkBox_ShowCakeLabels.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowCakeLabels.setChecked(True)
        self.checkBox_ShowCakeLabels.setObjectName("checkBox_ShowCakeLabels")
        self.gridLayout_11.addWidget(self.checkBox_ShowCakeLabels, 0, 0, 1, 1)
        self.checkBox_ShowWaterfall = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowWaterfall.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowWaterfall.setSizePolicy(sizePolicy)
        self.checkBox_ShowWaterfall.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowWaterfall.setChecked(True)
        self.checkBox_ShowWaterfall.setObjectName("checkBox_ShowWaterfall")
        self.gridLayout_11.addWidget(self.checkBox_ShowWaterfall, 1, 0, 1, 1)
        self.checkBox_ShowWaterfallLabels = QtWidgets.QCheckBox(self.groupBox_34)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowWaterfallLabels.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowWaterfallLabels.setSizePolicy(sizePolicy)
        self.checkBox_ShowWaterfallLabels.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowWaterfallLabels.setChecked(True)
        self.checkBox_ShowWaterfallLabels.setObjectName("checkBox_ShowWaterfallLabels")
        self.gridLayout_11.addWidget(self.checkBox_ShowWaterfallLabels, 2, 0, 1, 1)
        self.verticalLayout_31.addWidget(self.groupBox_34)
        self.groupBox_16 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_16.sizePolicy().hasHeightForWidth())
        self.groupBox_16.setSizePolicy(sizePolicy)
        self.groupBox_16.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.groupBox_16.setFlat(False)
        self.groupBox_16.setObjectName("groupBox_16")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.groupBox_16)
        self.gridLayout_7.setContentsMargins(12, -1, 12, 12)
        self.gridLayout_7.setVerticalSpacing(12)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.checkBox_NightView = QtWidgets.QCheckBox(self.groupBox_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_NightView.sizePolicy().hasHeightForWidth())
        self.checkBox_NightView.setSizePolicy(sizePolicy)
        self.checkBox_NightView.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_NightView.setChecked(True)
        self.checkBox_NightView.setObjectName("checkBox_NightView")
        self.gridLayout_7.addWidget(self.checkBox_NightView, 0, 1, 1, 1)
        self.checkBox_WhiteForPeak = QtWidgets.QCheckBox(self.groupBox_16)
        self.checkBox_WhiteForPeak.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_WhiteForPeak.setObjectName("checkBox_WhiteForPeak")
        self.gridLayout_7.addWidget(self.checkBox_WhiteForPeak, 1, 1, 1, 1)
        self.checkBox_ShowLargePnT = QtWidgets.QCheckBox(self.groupBox_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ShowLargePnT.sizePolicy().hasHeightForWidth())
        self.checkBox_ShowLargePnT.setSizePolicy(sizePolicy)
        self.checkBox_ShowLargePnT.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShowLargePnT.setChecked(False)
        self.checkBox_ShowLargePnT.setObjectName("checkBox_ShowLargePnT")
        self.gridLayout_7.addWidget(self.checkBox_ShowLargePnT, 1, 0, 1, 1)
        self.checkBox_ShortPlotTitle = QtWidgets.QCheckBox(self.groupBox_16)
        self.checkBox_ShortPlotTitle.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ShortPlotTitle.setObjectName("checkBox_ShortPlotTitle")
        self.gridLayout_7.addWidget(self.checkBox_ShortPlotTitle, 0, 0, 1, 1)
        self.verticalLayout_31.addWidget(self.groupBox_16)
        self.groupBox_24 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_24.sizePolicy().hasHeightForWidth())
        self.groupBox_24.setSizePolicy(sizePolicy)
        self.groupBox_24.setFlat(False)
        self.groupBox_24.setObjectName("groupBox_24")
        self.gridLayout_15 = QtWidgets.QGridLayout(self.groupBox_24)
        self.gridLayout_15.setContentsMargins(-1, 12, -1, 12)
        self.gridLayout_15.setVerticalSpacing(12)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.label_17 = QtWidgets.QLabel(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_17.sizePolicy().hasHeightForWidth())
        self.label_17.setSizePolicy(sizePolicy)
        self.label_17.setObjectName("label_17")
        self.gridLayout_15.addWidget(self.label_17, 0, 0, 1, 1)
        self.comboBox_BasePtnLineThickness = QtWidgets.QComboBox(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_BasePtnLineThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_BasePtnLineThickness.setSizePolicy(sizePolicy)
        self.comboBox_BasePtnLineThickness.setMinimumSize(QtCore.QSize(0, 20))
        self.comboBox_BasePtnLineThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_BasePtnLineThickness.setMaxCount(10)
        self.comboBox_BasePtnLineThickness.setObjectName("comboBox_BasePtnLineThickness")
        self.gridLayout_15.addWidget(self.comboBox_BasePtnLineThickness, 0, 1, 1, 1)
        self.comboBox_BkgnLineThickness = QtWidgets.QComboBox(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_BkgnLineThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_BkgnLineThickness.setSizePolicy(sizePolicy)
        self.comboBox_BkgnLineThickness.setMinimumSize(QtCore.QSize(0, 20))
        self.comboBox_BkgnLineThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_BkgnLineThickness.setObjectName("comboBox_BkgnLineThickness")
        self.gridLayout_15.addWidget(self.comboBox_BkgnLineThickness, 1, 1, 1, 1)
        self.label_24 = QtWidgets.QLabel(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_24.sizePolicy().hasHeightForWidth())
        self.label_24.setSizePolicy(sizePolicy)
        self.label_24.setObjectName("label_24")
        self.gridLayout_15.addWidget(self.label_24, 1, 0, 1, 1)
        self.label_25 = QtWidgets.QLabel(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_25.sizePolicy().hasHeightForWidth())
        self.label_25.setSizePolicy(sizePolicy)
        self.label_25.setObjectName("label_25")
        self.gridLayout_15.addWidget(self.label_25, 0, 3, 1, 1)
        self.comboBox_WaterfallLineThickness = QtWidgets.QComboBox(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_WaterfallLineThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_WaterfallLineThickness.setSizePolicy(sizePolicy)
        self.comboBox_WaterfallLineThickness.setMinimumSize(QtCore.QSize(0, 20))
        self.comboBox_WaterfallLineThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_WaterfallLineThickness.setObjectName("comboBox_WaterfallLineThickness")
        self.gridLayout_15.addWidget(self.comboBox_WaterfallLineThickness, 0, 4, 1, 1)
        self.label_26 = QtWidgets.QLabel(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_26.sizePolicy().hasHeightForWidth())
        self.label_26.setSizePolicy(sizePolicy)
        self.label_26.setObjectName("label_26")
        self.gridLayout_15.addWidget(self.label_26, 1, 3, 1, 1)
        self.comboBox_VertCursorThickness = QtWidgets.QComboBox(self.groupBox_24)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_VertCursorThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_VertCursorThickness.setSizePolicy(sizePolicy)
        self.comboBox_VertCursorThickness.setMinimumSize(QtCore.QSize(0, 20))
        self.comboBox_VertCursorThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_VertCursorThickness.setObjectName("comboBox_VertCursorThickness")
        self.gridLayout_15.addWidget(self.comboBox_VertCursorThickness, 1, 4, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_15.addItem(spacerItem1, 0, 2, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_15.addItem(spacerItem2, 1, 2, 1, 1)
        self.verticalLayout_31.addWidget(self.groupBox_24)
        self.groupBox_17 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_17.sizePolicy().hasHeightForWidth())
        self.groupBox_17.setSizePolicy(sizePolicy)
        self.groupBox_17.setObjectName("groupBox_17")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.groupBox_17)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.checkBox_NavDPP = QtWidgets.QCheckBox(self.groupBox_17)
        self.checkBox_NavDPP.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_NavDPP.setMaximumSize(QtCore.QSize(200, 16777215))
        self.checkBox_NavDPP.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.checkBox_NavDPP.setChecked(False)
        self.checkBox_NavDPP.setObjectName("checkBox_NavDPP")
        self.verticalLayout_30.addWidget(self.checkBox_NavDPP)
        self.checkBox_AutoGenDPP = QtWidgets.QCheckBox(self.groupBox_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_AutoGenDPP.sizePolicy().hasHeightForWidth())
        self.checkBox_AutoGenDPP.setSizePolicy(sizePolicy)
        self.checkBox_AutoGenDPP.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_AutoGenDPP.setMaximumSize(QtCore.QSize(250, 16777215))
        self.checkBox_AutoGenDPP.setChecked(False)
        self.checkBox_AutoGenDPP.setObjectName("checkBox_AutoGenDPP")
        self.verticalLayout_30.addWidget(self.checkBox_AutoGenDPP)
        self.checkBox_SaveDPPMove = QtWidgets.QCheckBox(self.groupBox_17)
        self.checkBox_SaveDPPMove.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_SaveDPPMove.setMaximumSize(QtCore.QSize(250, 16777215))
        self.checkBox_SaveDPPMove.setChecked(True)
        self.checkBox_SaveDPPMove.setObjectName("checkBox_SaveDPPMove")
        self.verticalLayout_30.addWidget(self.checkBox_SaveDPPMove)
        self.verticalLayout_31.addWidget(self.groupBox_17)
        self.groupBox_22 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_22.sizePolicy().hasHeightForWidth())
        self.groupBox_22.setSizePolicy(sizePolicy)
        self.groupBox_22.setFlat(False)
        self.groupBox_22.setObjectName("groupBox_22")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.groupBox_22)
        self.gridLayout_14.setVerticalSpacing(12)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.checkBox_ForceOverwite = QtWidgets.QCheckBox(self.groupBox_22)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_ForceOverwite.sizePolicy().hasHeightForWidth())
        self.checkBox_ForceOverwite.setSizePolicy(sizePolicy)
        self.checkBox_ForceOverwite.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_ForceOverwite.setChecked(True)
        self.checkBox_ForceOverwite.setObjectName("checkBox_ForceOverwite")
        self.gridLayout_14.addWidget(self.checkBox_ForceOverwite, 0, 0, 1, 1)
        self.checkBox_IgnoreDirChange = QtWidgets.QCheckBox(self.groupBox_22)
        self.checkBox_IgnoreDirChange.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_IgnoreDirChange.setChecked(True)
        self.checkBox_IgnoreDirChange.setObjectName("checkBox_IgnoreDirChange")
        self.gridLayout_14.addWidget(self.checkBox_IgnoreDirChange, 0, 1, 1, 1)
        self.checkBox_AutogenMissing = QtWidgets.QCheckBox(self.groupBox_22)
        self.checkBox_AutogenMissing.setMinimumSize(QtCore.QSize(0, 20))
        self.checkBox_AutogenMissing.setChecked(True)
        self.checkBox_AutogenMissing.setObjectName("checkBox_AutogenMissing")
        self.gridLayout_14.addWidget(self.checkBox_AutogenMissing, 1, 0, 1, 2)
        self.verticalLayout_31.addWidget(self.groupBox_22)
        self.groupBox_12 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_12.sizePolicy().hasHeightForWidth())
        self.groupBox_12.setSizePolicy(sizePolicy)
        self.groupBox_12.setFlat(False)
        self.groupBox_12.setObjectName("groupBox_12")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_12)
        self.gridLayout.setObjectName("gridLayout")
        self.pushButton_LoadPPSS = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_LoadPPSS.sizePolicy().hasHeightForWidth())
        self.pushButton_LoadPPSS.setSizePolicy(sizePolicy)
        self.pushButton_LoadPPSS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_LoadPPSS.setObjectName("pushButton_LoadPPSS")
        self.gridLayout.addWidget(self.pushButton_LoadPPSS, 0, 0, 1, 1)
        self.pushButton_SavePPSS = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SavePPSS.sizePolicy().hasHeightForWidth())
        self.pushButton_SavePPSS.setSizePolicy(sizePolicy)
        self.pushButton_SavePPSS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_SavePPSS.setObjectName("pushButton_SavePPSS")
        self.gridLayout.addWidget(self.pushButton_SavePPSS, 0, 1, 1, 1)
        self.pushButton_ZipSession = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ZipSession.sizePolicy().hasHeightForWidth())
        self.pushButton_ZipSession.setSizePolicy(sizePolicy)
        self.pushButton_ZipSession.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_ZipSession.setObjectName("pushButton_ZipSession")
        self.gridLayout.addWidget(self.pushButton_ZipSession, 1, 0, 1, 1)
        self.pushButton_SaveDPPandPPSS = QtWidgets.QPushButton(self.groupBox_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SaveDPPandPPSS.sizePolicy().hasHeightForWidth())
        self.pushButton_SaveDPPandPPSS.setSizePolicy(sizePolicy)
        self.pushButton_SaveDPPandPPSS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_SaveDPPandPPSS.setObjectName("pushButton_SaveDPPandPPSS")
        self.gridLayout.addWidget(self.pushButton_SaveDPPandPPSS, 1, 1, 1, 1)
        self.verticalLayout_31.addWidget(self.groupBox_12)
        self.groupBox_10 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_10.sizePolicy().hasHeightForWidth())
        self.groupBox_10.setSizePolicy(sizePolicy)
        self.groupBox_10.setFlat(False)
        self.groupBox_10.setObjectName("groupBox_10")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.groupBox_10)
        self.gridLayout_6.setVerticalSpacing(12)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.pushButton_DelTempCake = QtWidgets.QPushButton(self.groupBox_10)
        self.pushButton_DelTempCake.setObjectName("pushButton_DelTempCake")
        self.gridLayout_6.addWidget(self.pushButton_DelTempCake, 1, 0, 1, 1)
        self.checkBox_UseTempCake = QtWidgets.QCheckBox(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_UseTempCake.sizePolicy().hasHeightForWidth())
        self.checkBox_UseTempCake.setSizePolicy(sizePolicy)
        self.checkBox_UseTempCake.setChecked(True)
        self.checkBox_UseTempCake.setObjectName("checkBox_UseTempCake")
        self.gridLayout_6.addWidget(self.checkBox_UseTempCake, 1, 1, 1, 1)
        self.pushButton_DelTempCHI = QtWidgets.QPushButton(self.groupBox_10)
        self.pushButton_DelTempCHI.setObjectName("pushButton_DelTempCHI")
        self.gridLayout_6.addWidget(self.pushButton_DelTempCHI, 0, 0, 1, 1)
        self.checkBox_UseTempBGSub = QtWidgets.QCheckBox(self.groupBox_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_UseTempBGSub.sizePolicy().hasHeightForWidth())
        self.checkBox_UseTempBGSub.setSizePolicy(sizePolicy)
        self.checkBox_UseTempBGSub.setChecked(True)
        self.checkBox_UseTempBGSub.setObjectName("checkBox_UseTempBGSub")
        self.gridLayout_6.addWidget(self.checkBox_UseTempBGSub, 0, 1, 1, 1)
        self.verticalLayout_31.addWidget(self.groupBox_10)
        self.scrollArea_2.setWidget(self.scrollAreaWidgetContents_2)
        self.verticalLayout_6.addWidget(self.scrollArea_2)
        self.tabWidget_3.addTab(self.tabWidget_3Page2, "")
        self.tabWidget_3Page3 = QtWidgets.QWidget()
        self.tabWidget_3Page3.setObjectName("tabWidget_3Page3")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self.tabWidget_3Page3)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.frame_BackupTools = QtWidgets.QFrame(self.tabWidget_3Page3)
        self.frame_BackupTools.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_BackupTools.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_BackupTools.setObjectName("frame_BackupTools")
        self.horizontalLayout_BackupTools = QtWidgets.QHBoxLayout(self.frame_BackupTools)
        self.horizontalLayout_BackupTools.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_BackupTools.setObjectName("horizontalLayout_BackupTools")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_BackupTools.addItem(spacerItem1)
        self.pushButton_BackupRestore = QtWidgets.QPushButton(self.frame_BackupTools)
        self.pushButton_BackupRestore.setMinimumSize(QtCore.QSize(40, 25))
        self.pushButton_BackupRestore.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_BackupRestore.setObjectName("pushButton_BackupRestore")
        self.horizontalLayout_BackupTools.addWidget(self.pushButton_BackupRestore)
        self.verticalLayout_43.addWidget(self.frame_BackupTools)
        self.tableWidget_BackupInfo = QtWidgets.QTableWidget(self.tabWidget_3Page3)
        self.tableWidget_BackupInfo.setObjectName("tableWidget_BackupInfo")
        self.tableWidget_BackupInfo.setColumnCount(0)
        self.tableWidget_BackupInfo.setRowCount(0)
        self.tableWidget_BackupInfo.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableWidget_BackupInfo.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.verticalLayout_43.addWidget(self.tableWidget_BackupInfo)
        self.tabWidget_3.addTab(self.tabWidget_3Page3, "")
        self.verticalLayout_18.addWidget(self.tabWidget_3)
        self.tabWidget.addTab(self.tab_Main, "")
        self.tab_JCPDSList2 = QtWidgets.QWidget()
        self.tab_JCPDSList2.setObjectName("tab_JCPDSList2")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.tab_JCPDSList2)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.tabWidget1 = QtWidgets.QTabWidget(self.tab_JCPDSList2)
        self.tabWidget1.setObjectName("tabWidget1")
        self.tabWidgetPage1 = QtWidgets.QWidget()
        self.tabWidgetPage1.setObjectName("tabWidgetPage1")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout(self.tabWidgetPage1)
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.scrollArea_3 = QtWidgets.QScrollArea(self.tabWidgetPage1)
        self.scrollArea_3.setWidgetResizable(True)
        self.scrollArea_3.setObjectName("scrollArea_3")
        self.scrollAreaWidgetContents_3 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_3.setGeometry(QtCore.QRect(0, 0, 568, 637))
        self.scrollAreaWidgetContents_3.setObjectName("scrollAreaWidgetContents_3")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_3)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.groupBox = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setAutoFillBackground(False)
        self.groupBox.setFlat(False)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_10.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.frame_17 = QtWidgets.QFrame(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_17.sizePolicy().hasHeightForWidth())
        self.frame_17.setSizePolicy(sizePolicy)
        self.frame_17.setMinimumSize(QtCore.QSize(0, 0))
        self.frame_17.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_17.setObjectName("frame_17")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.frame_17)
        self.horizontalLayout_17.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_17.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.doubleSpinBox_Temperature = QtWidgets.QDoubleSpinBox(self.frame_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_Temperature.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_Temperature.setSizePolicy(sizePolicy)
        self.doubleSpinBox_Temperature.setMinimumSize(QtCore.QSize(0, 40))
        self.doubleSpinBox_Temperature.setBaseSize(QtCore.QSize(0, 50))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(24)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(9)
        self.doubleSpinBox_Temperature.setFont(font)
        self.doubleSpinBox_Temperature.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_Temperature.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.doubleSpinBox_Temperature.setAutoFillBackground(False)
        self.doubleSpinBox_Temperature.setStyleSheet("font: 75 24pt \"Helvetica\";")
        self.doubleSpinBox_Temperature.setFrame(False)
        self.doubleSpinBox_Temperature.setAlignment(QtCore.Qt.AlignCenter)
        self.doubleSpinBox_Temperature.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.doubleSpinBox_Temperature.setDecimals(0)
        self.doubleSpinBox_Temperature.setMaximum(10000.0)
        self.doubleSpinBox_Temperature.setSingleStep(1000.0)
        self.doubleSpinBox_Temperature.setProperty("value", 300.0)
        self.doubleSpinBox_Temperature.setObjectName("doubleSpinBox_Temperature")
        self.horizontalLayout_17.addWidget(self.doubleSpinBox_Temperature)
        self.pushButton_RoomT = QtWidgets.QPushButton(self.frame_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_RoomT.sizePolicy().hasHeightForWidth())
        self.pushButton_RoomT.setSizePolicy(sizePolicy)
        self.pushButton_RoomT.setMinimumSize(QtCore.QSize(30, 0))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_RoomT.setFont(font)
        self.pushButton_RoomT.setObjectName("pushButton_RoomT")
        self.horizontalLayout_17.addWidget(self.pushButton_RoomT)
        self.spinBox_TStep = QtWidgets.QSpinBox(self.frame_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_TStep.sizePolicy().hasHeightForWidth())
        self.spinBox_TStep.setSizePolicy(sizePolicy)
        self.spinBox_TStep.setMinimumSize(QtCore.QSize(60, 25))
        self.spinBox_TStep.setMaximumSize(QtCore.QSize(60, 16777215))
        self.spinBox_TStep.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_TStep.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_TStep.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.spinBox_TStep.setMaximum(8000)
        self.spinBox_TStep.setProperty("value", 100)
        self.spinBox_TStep.setObjectName("spinBox_TStep")
        self.horizontalLayout_17.addWidget(self.spinBox_TStep)
        self.pushButton_SetTStepTo100 = QtWidgets.QPushButton(self.frame_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetTStepTo100.sizePolicy().hasHeightForWidth())
        self.pushButton_SetTStepTo100.setSizePolicy(sizePolicy)
        self.pushButton_SetTStepTo100.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetTStepTo100.setObjectName("pushButton_SetTStepTo100")
        self.horizontalLayout_17.addWidget(self.pushButton_SetTStepTo100)
        self.pushButton_SetTStepTo1000 = QtWidgets.QPushButton(self.frame_17)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetTStepTo1000.sizePolicy().hasHeightForWidth())
        self.pushButton_SetTStepTo1000.setSizePolicy(sizePolicy)
        self.pushButton_SetTStepTo1000.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetTStepTo1000.setObjectName("pushButton_SetTStepTo1000")
        self.horizontalLayout_17.addWidget(self.pushButton_SetTStepTo1000)
        self.gridLayout_10.addWidget(self.frame_17, 4, 1, 1, 1)
        self.frame_16 = QtWidgets.QFrame(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_16.sizePolicy().hasHeightForWidth())
        self.frame_16.setSizePolicy(sizePolicy)
        self.frame_16.setMinimumSize(QtCore.QSize(0, 0))
        self.frame_16.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.frame_16.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_16.setObjectName("frame_16")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.frame_16)
        self.horizontalLayout_15.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.horizontalLayout_15.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.doubleSpinBox_Pressure = QtWidgets.QDoubleSpinBox(self.frame_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_Pressure.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_Pressure.setSizePolicy(sizePolicy)
        self.doubleSpinBox_Pressure.setMinimumSize(QtCore.QSize(0, 40))
        self.doubleSpinBox_Pressure.setSizeIncrement(QtCore.QSize(0, 0))
        self.doubleSpinBox_Pressure.setBaseSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(24)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(9)
        self.doubleSpinBox_Pressure.setFont(font)
        self.doubleSpinBox_Pressure.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_Pressure.setStyleSheet("font: 75 24pt \"Helvetica\";")
        self.doubleSpinBox_Pressure.setFrame(False)
        self.doubleSpinBox_Pressure.setAlignment(QtCore.Qt.AlignCenter)
        self.doubleSpinBox_Pressure.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.doubleSpinBox_Pressure.setDecimals(2)
        self.doubleSpinBox_Pressure.setMaximum(1000.0)
        self.doubleSpinBox_Pressure.setProperty("value", 10.0)
        self.doubleSpinBox_Pressure.setObjectName("doubleSpinBox_Pressure")
        self.horizontalLayout_15.addWidget(self.doubleSpinBox_Pressure)
        self.pushButton_1bar = QtWidgets.QPushButton(self.frame_16)
        self.pushButton_1bar.setObjectName("pushButton_1bar")
        self.horizontalLayout_15.addWidget(self.pushButton_1bar)
        self.doubleSpinBox_PStep = QtWidgets.QDoubleSpinBox(self.frame_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_PStep.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_PStep.setSizePolicy(sizePolicy)
        self.doubleSpinBox_PStep.setMinimumSize(QtCore.QSize(60, 25))
        self.doubleSpinBox_PStep.setMaximumSize(QtCore.QSize(60, 16777215))
        self.doubleSpinBox_PStep.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_PStep.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_PStep.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.doubleSpinBox_PStep.setProperty("showGroupSeparator", False)
        self.doubleSpinBox_PStep.setMaximum(100.0)
        self.doubleSpinBox_PStep.setSingleStep(0.01)
        self.doubleSpinBox_PStep.setProperty("value", 1.0)
        self.doubleSpinBox_PStep.setObjectName("doubleSpinBox_PStep")
        self.horizontalLayout_15.addWidget(self.doubleSpinBox_PStep)
        self.pushButton_SetPStepTo1 = QtWidgets.QPushButton(self.frame_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetPStepTo1.sizePolicy().hasHeightForWidth())
        self.pushButton_SetPStepTo1.setSizePolicy(sizePolicy)
        self.pushButton_SetPStepTo1.setMinimumSize(QtCore.QSize(50, 0))
        self.pushButton_SetPStepTo1.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetPStepTo1.setObjectName("pushButton_SetPStepTo1")
        self.horizontalLayout_15.addWidget(self.pushButton_SetPStepTo1)
        self.pushButton_SetPStepTo10 = QtWidgets.QPushButton(self.frame_16)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetPStepTo10.sizePolicy().hasHeightForWidth())
        self.pushButton_SetPStepTo10.setSizePolicy(sizePolicy)
        self.pushButton_SetPStepTo10.setMinimumSize(QtCore.QSize(50, 0))
        self.pushButton_SetPStepTo10.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton_SetPStepTo10.setObjectName("pushButton_SetPStepTo10")
        self.horizontalLayout_15.addWidget(self.pushButton_SetPStepTo10)
        self.gridLayout_10.addWidget(self.frame_16, 0, 1, 1, 1)
        self.verticalLayout_32.addWidget(self.groupBox)
        self.groupBox_8 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_8.sizePolicy().hasHeightForWidth())
        self.groupBox_8.setSizePolicy(sizePolicy)
        self.groupBox_8.setTitle("")
        self.groupBox_8.setFlat(False)
        self.groupBox_8.setObjectName("groupBox_8")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_8)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.pushButton_AddToJlist = QtWidgets.QPushButton(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_AddToJlist.sizePolicy().hasHeightForWidth())
        self.pushButton_AddToJlist.setSizePolicy(sizePolicy)
        self.pushButton_AddToJlist.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_AddToJlist.setMaximumSize(QtCore.QSize(32, 25))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_AddToJlist.setFont(font)
        self.pushButton_AddToJlist.setObjectName("pushButton_AddToJlist")
        self.gridLayout_2.addWidget(self.pushButton_AddToJlist, 0, 0, 1, 1)
        self.pushButton_ViewJCPDS = QtWidgets.QPushButton(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ViewJCPDS.sizePolicy().hasHeightForWidth())
        self.pushButton_ViewJCPDS.setSizePolicy(sizePolicy)
        self.pushButton_ViewJCPDS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_ViewJCPDS.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_ViewJCPDS.setFont(font)
        self.pushButton_ViewJCPDS.setObjectName("pushButton_ViewJCPDS")
        self.gridLayout_2.addWidget(self.pushButton_ViewJCPDS, 0, 6, 1, 1)
        self.pushButton_MoveDown = QtWidgets.QPushButton(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_MoveDown.sizePolicy().hasHeightForWidth())
        self.pushButton_MoveDown.setSizePolicy(sizePolicy)
        self.pushButton_MoveDown.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_MoveDown.setMaximumSize(QtCore.QSize(32, 25))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_MoveDown.setFont(font)
        self.pushButton_MoveDown.setObjectName("pushButton_MoveDown")
        self.gridLayout_2.addWidget(self.pushButton_MoveDown, 0, 3, 1, 1)
        self.pushButton_MoveUp = QtWidgets.QPushButton(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_MoveUp.sizePolicy().hasHeightForWidth())
        self.pushButton_MoveUp.setSizePolicy(sizePolicy)
        self.pushButton_MoveUp.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_MoveUp.setMaximumSize(QtCore.QSize(32, 25))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_MoveUp.setFont(font)
        self.pushButton_MoveUp.setObjectName("pushButton_MoveUp")
        self.gridLayout_2.addWidget(self.pushButton_MoveUp, 0, 2, 1, 1)
        self.pushButton_SaveTwkJCPDS = QtWidgets.QPushButton(self.groupBox_8)
        self.pushButton_SaveTwkJCPDS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_SaveTwkJCPDS.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_SaveTwkJCPDS.setObjectName("pushButton_SaveTwkJCPDS")
        self.gridLayout_2.addWidget(self.pushButton_SaveTwkJCPDS, 0, 4, 1, 1)
        self.pushButton_RemoveJCPDS = QtWidgets.QPushButton(self.groupBox_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_RemoveJCPDS.sizePolicy().hasHeightForWidth())
        self.pushButton_RemoveJCPDS.setSizePolicy(sizePolicy)
        self.pushButton_RemoveJCPDS.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_RemoveJCPDS.setMaximumSize(QtCore.QSize(32, 25))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_RemoveJCPDS.setFont(font)
        self.pushButton_RemoveJCPDS.setObjectName("pushButton_RemoveJCPDS")
        self.gridLayout_2.addWidget(self.pushButton_RemoveJCPDS, 0, 1, 1, 1)
        self.pushButton_savePeakPos = QtWidgets.QPushButton(self.groupBox_8)
        self.pushButton_savePeakPos.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_savePeakPos.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_savePeakPos.setObjectName("pushButton_savePeakPos")
        self.gridLayout_2.addWidget(self.pushButton_savePeakPos, 0, 7, 1, 1)
        self.verticalLayout_32.addWidget(self.groupBox_8)
        self.tableWidget_JCPDS = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_JCPDS.sizePolicy().hasHeightForWidth())
        self.tableWidget_JCPDS.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.tableWidget_JCPDS.setFont(font)
        self.tableWidget_JCPDS.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.tableWidget_JCPDS.setWordWrap(False)
        self.tableWidget_JCPDS.setColumnCount(0)
        self.tableWidget_JCPDS.setObjectName("tableWidget_JCPDS")
        self.tableWidget_JCPDS.setRowCount(0)
        self.tableWidget_JCPDS.horizontalHeader().setVisible(False)
        self.tableWidget_JCPDS.horizontalHeader().setCascadingSectionResizes(True)
        self.tableWidget_JCPDS.verticalHeader().setVisible(False)
        self.tableWidget_JCPDS.verticalHeader().setCascadingSectionResizes(True)
        self.verticalLayout_32.addWidget(self.tableWidget_JCPDS)
        self.frame_25 = QtWidgets.QFrame(self.scrollAreaWidgetContents_3)
        self.frame_25.setObjectName("frame_25")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout(self.frame_25)
        self.horizontalLayout_19.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        self.pushButton_UpdateJCPDSSteps = QtWidgets.QPushButton(self.frame_25)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_UpdateJCPDSSteps.sizePolicy().hasHeightForWidth())
        self.pushButton_UpdateJCPDSSteps.setSizePolicy(sizePolicy)
        self.pushButton_UpdateJCPDSSteps.setObjectName("pushButton_UpdateJCPDSSteps")
        self.horizontalLayout_19.addWidget(self.pushButton_UpdateJCPDSSteps)
        self.doubleSpinBox_JCPDSStep = QtWidgets.QDoubleSpinBox(self.frame_25)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_JCPDSStep.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_JCPDSStep.setSizePolicy(sizePolicy)
        self.doubleSpinBox_JCPDSStep.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_JCPDSStep.setMaximumSize(QtCore.QSize(100, 16777215))
        self.doubleSpinBox_JCPDSStep.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_JCPDSStep.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_JCPDSStep.setButtonSymbols(QtWidgets.QAbstractSpinBox.UpDownArrows)
        self.doubleSpinBox_JCPDSStep.setDecimals(3)
        self.doubleSpinBox_JCPDSStep.setMaximum(1.0)
        self.doubleSpinBox_JCPDSStep.setSingleStep(0.001)
        self.doubleSpinBox_JCPDSStep.setProperty("value", 0.001)
        self.doubleSpinBox_JCPDSStep.setObjectName("doubleSpinBox_JCPDSStep")
        self.horizontalLayout_19.addWidget(self.doubleSpinBox_JCPDSStep)
        self.pushButton_SetJCPDSStepTo0001 = QtWidgets.QPushButton(self.frame_25)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetJCPDSStepTo0001.sizePolicy().hasHeightForWidth())
        self.pushButton_SetJCPDSStepTo0001.setSizePolicy(sizePolicy)
        self.pushButton_SetJCPDSStepTo0001.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton_SetJCPDSStepTo0001.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_SetJCPDSStepTo0001.setObjectName("pushButton_SetJCPDSStepTo0001")
        self.horizontalLayout_19.addWidget(self.pushButton_SetJCPDSStepTo0001)
        self.pushButton_SetJCPDSStepTo001 = QtWidgets.QPushButton(self.frame_25)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetJCPDSStepTo001.sizePolicy().hasHeightForWidth())
        self.pushButton_SetJCPDSStepTo001.setSizePolicy(sizePolicy)
        self.pushButton_SetJCPDSStepTo001.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_SetJCPDSStepTo001.setObjectName("pushButton_SetJCPDSStepTo001")
        self.horizontalLayout_19.addWidget(self.pushButton_SetJCPDSStepTo001)
        self.pushButton_SetJCPDSStepTo01 = QtWidgets.QPushButton(self.frame_25)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetJCPDSStepTo01.sizePolicy().hasHeightForWidth())
        self.pushButton_SetJCPDSStepTo01.setSizePolicy(sizePolicy)
        self.pushButton_SetJCPDSStepTo01.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_SetJCPDSStepTo01.setObjectName("pushButton_SetJCPDSStepTo01")
        self.horizontalLayout_19.addWidget(self.pushButton_SetJCPDSStepTo01)
        self.verticalLayout_32.addWidget(self.frame_25)
        self.scrollArea_3.setWidget(self.scrollAreaWidgetContents_3)
        self.verticalLayout_19.addWidget(self.scrollArea_3)
        self.tabWidget1.addTab(self.tabWidgetPage1, "")
        self.tabWidgetPage2 = QtWidgets.QWidget()
        self.tabWidgetPage2.setObjectName("tabWidgetPage2")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout(self.tabWidgetPage2)
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.scrollArea_4 = QtWidgets.QScrollArea(self.tabWidgetPage2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.scrollArea_4.sizePolicy().hasHeightForWidth())
        self.scrollArea_4.setSizePolicy(sizePolicy)
        self.scrollArea_4.setMinimumSize(QtCore.QSize(0, 0))
        self.scrollArea_4.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.scrollArea_4.setWidgetResizable(True)
        self.scrollArea_4.setObjectName("scrollArea_4")
        self.scrollAreaWidgetContents_4 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_4.setGeometry(QtCore.QRect(0, 0, 391, 533))
        self.scrollAreaWidgetContents_4.setObjectName("scrollAreaWidgetContents_4")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_4)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.pushButton_ForceUpdatePlot = QtWidgets.QPushButton(self.scrollAreaWidgetContents_4)
        self.pushButton_ForceUpdatePlot.setMinimumSize(QtCore.QSize(0, 20))
        self.pushButton_ForceUpdatePlot.setObjectName("pushButton_ForceUpdatePlot")
        self.verticalLayout_33.addWidget(self.pushButton_ForceUpdatePlot)
        self.groupBox_18 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_18.sizePolicy().hasHeightForWidth())
        self.groupBox_18.setSizePolicy(sizePolicy)
        self.groupBox_18.setFlat(False)
        self.groupBox_18.setObjectName("groupBox_18")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.groupBox_18)
        self.verticalLayout_12.setContentsMargins(-1, 12, -1, 12)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.textEdit_Jlist = QtWidgets.QTextEdit(self.groupBox_18)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textEdit_Jlist.sizePolicy().hasHeightForWidth())
        self.textEdit_Jlist.setSizePolicy(sizePolicy)
        self.textEdit_Jlist.setMinimumSize(QtCore.QSize(0, 20))
        self.textEdit_Jlist.setMaximumSize(QtCore.QSize(16777215, 35))
        self.textEdit_Jlist.setReadOnly(True)
        self.textEdit_Jlist.setObjectName("textEdit_Jlist")
        self.verticalLayout_12.addWidget(self.textEdit_Jlist)
        self.verticalLayout_33.addWidget(self.groupBox_18)
        self.groupBox_20 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_20.sizePolicy().hasHeightForWidth())
        self.groupBox_20.setSizePolicy(sizePolicy)
        self.groupBox_20.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_20.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_20.setFlat(False)
        self.groupBox_20.setObjectName("groupBox_20")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.groupBox_20)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.label_27 = QtWidgets.QLabel(self.groupBox_20)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_27.sizePolicy().hasHeightForWidth())
        self.label_27.setSizePolicy(sizePolicy)
        self.label_27.setAlignment(QtCore.Qt.AlignCenter)
        self.label_27.setObjectName("label_27")
        self.verticalLayout_23.addWidget(self.label_27)
        self.horizontalSlider_JCPDSBarScale = QtWidgets.QSlider(self.groupBox_20)
        self.horizontalSlider_JCPDSBarScale.setMinimumSize(QtCore.QSize(0, 20))
        self.horizontalSlider_JCPDSBarScale.setMaximum(100)
        self.horizontalSlider_JCPDSBarScale.setProperty("value", 90)
        self.horizontalSlider_JCPDSBarScale.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_JCPDSBarScale.setObjectName("horizontalSlider_JCPDSBarScale")
        self.verticalLayout_23.addWidget(self.horizontalSlider_JCPDSBarScale)
        self.label_28 = QtWidgets.QLabel(self.groupBox_20)
        self.label_28.setAlignment(QtCore.Qt.AlignCenter)
        self.label_28.setObjectName("label_28")
        self.verticalLayout_23.addWidget(self.label_28)
        self.horizontalSlider_JCPDSBarPosition = QtWidgets.QSlider(self.groupBox_20)
        self.horizontalSlider_JCPDSBarPosition.setMinimumSize(QtCore.QSize(0, 20))
        self.horizontalSlider_JCPDSBarPosition.setMinimum(-50)
        self.horizontalSlider_JCPDSBarPosition.setMaximum(100)
        self.horizontalSlider_JCPDSBarPosition.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_JCPDSBarPosition.setObjectName("horizontalSlider_JCPDSBarPosition")
        self.verticalLayout_23.addWidget(self.horizontalSlider_JCPDSBarPosition)
        self.verticalLayout_33.addWidget(self.groupBox_20)
        self.groupBox_26 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_26.sizePolicy().hasHeightForWidth())
        self.groupBox_26.setSizePolicy(sizePolicy)
        self.groupBox_26.setFlat(False)
        self.groupBox_26.setObjectName("groupBox_26")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.groupBox_26)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.checkBox_UseJCPDSTable1bar = QtWidgets.QCheckBox(self.groupBox_26)
        self.checkBox_UseJCPDSTable1bar.setObjectName("checkBox_UseJCPDSTable1bar")
        self.verticalLayout_20.addWidget(self.checkBox_UseJCPDSTable1bar)
        self.verticalLayout_33.addWidget(self.groupBox_26)
        self.groupBox_13 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_13.sizePolicy().hasHeightForWidth())
        self.groupBox_13.setSizePolicy(sizePolicy)
        self.groupBox_13.setFlat(False)
        self.groupBox_13.setObjectName("groupBox_13")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.groupBox_13)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_15 = QtWidgets.QLabel(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_15.sizePolicy().hasHeightForWidth())
        self.label_15.setSizePolicy(sizePolicy)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_4.addWidget(self.label_15)
        self.comboBox_PnTFontSize = QtWidgets.QComboBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_PnTFontSize.sizePolicy().hasHeightForWidth())
        self.comboBox_PnTFontSize.setSizePolicy(sizePolicy)
        self.comboBox_PnTFontSize.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_PnTFontSize.setObjectName("comboBox_PnTFontSize")
        self.horizontalLayout_4.addWidget(self.comboBox_PnTFontSize)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem3)
        self.label_3 = QtWidgets.QLabel(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_4.addWidget(self.label_3)
        self.comboBox_HKLFontSize = QtWidgets.QComboBox(self.groupBox_13)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_HKLFontSize.sizePolicy().hasHeightForWidth())
        self.comboBox_HKLFontSize.setSizePolicy(sizePolicy)
        self.comboBox_HKLFontSize.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_HKLFontSize.setObjectName("comboBox_HKLFontSize")
        self.horizontalLayout_4.addWidget(self.comboBox_HKLFontSize)
        self.verticalLayout_33.addWidget(self.groupBox_13)
        self.groupBox_27 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_27.sizePolicy().hasHeightForWidth())
        self.groupBox_27.setSizePolicy(sizePolicy)
        self.groupBox_27.setFlat(False)
        self.groupBox_27.setObjectName("groupBox_27")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_27)
        self.gridLayout_3.setContentsMargins(12, -1, 12, -1)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_30 = QtWidgets.QLabel(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_30.sizePolicy().hasHeightForWidth())
        self.label_30.setSizePolicy(sizePolicy)
        self.label_30.setObjectName("label_30")
        self.gridLayout_3.addWidget(self.label_30, 0, 3, 1, 1)
        self.doubleSpinBox_JCPDS_ptn_Alpha = QtWidgets.QDoubleSpinBox(self.groupBox_27)
        self.doubleSpinBox_JCPDS_ptn_Alpha.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_JCPDS_ptn_Alpha.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_JCPDS_ptn_Alpha.setMaximum(1.0)
        self.doubleSpinBox_JCPDS_ptn_Alpha.setSingleStep(0.01)
        self.doubleSpinBox_JCPDS_ptn_Alpha.setProperty("value", 1.0)
        self.doubleSpinBox_JCPDS_ptn_Alpha.setObjectName("doubleSpinBox_JCPDS_ptn_Alpha")
        self.gridLayout_3.addWidget(self.doubleSpinBox_JCPDS_ptn_Alpha, 0, 1, 1, 1)
        self.comboBox_CakeJCPDSBarThickness = QtWidgets.QComboBox(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_CakeJCPDSBarThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_CakeJCPDSBarThickness.setSizePolicy(sizePolicy)
        self.comboBox_CakeJCPDSBarThickness.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_CakeJCPDSBarThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_CakeJCPDSBarThickness.setMaxCount(10)
        self.comboBox_CakeJCPDSBarThickness.setObjectName("comboBox_CakeJCPDSBarThickness")
        self.gridLayout_3.addWidget(self.comboBox_CakeJCPDSBarThickness, 1, 4, 1, 1)
        self.label_23 = QtWidgets.QLabel(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_23.sizePolicy().hasHeightForWidth())
        self.label_23.setSizePolicy(sizePolicy)
        self.label_23.setObjectName("label_23")
        self.gridLayout_3.addWidget(self.label_23, 1, 3, 1, 1)
        self.doubleSpinBox_JCPDS_cake_Alpha = QtWidgets.QDoubleSpinBox(self.groupBox_27)
        self.doubleSpinBox_JCPDS_cake_Alpha.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_JCPDS_cake_Alpha.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_JCPDS_cake_Alpha.setMaximum(1.0)
        self.doubleSpinBox_JCPDS_cake_Alpha.setSingleStep(0.01)
        self.doubleSpinBox_JCPDS_cake_Alpha.setProperty("value", 0.5)
        self.doubleSpinBox_JCPDS_cake_Alpha.setObjectName("doubleSpinBox_JCPDS_cake_Alpha")
        self.gridLayout_3.addWidget(self.doubleSpinBox_JCPDS_cake_Alpha, 0, 4, 1, 1)
        self.comboBox_PtnJCPDSBarThickness = QtWidgets.QComboBox(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBox_PtnJCPDSBarThickness.sizePolicy().hasHeightForWidth())
        self.comboBox_PtnJCPDSBarThickness.setSizePolicy(sizePolicy)
        self.comboBox_PtnJCPDSBarThickness.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_PtnJCPDSBarThickness.setLayoutDirection(QtCore.Qt.RightToLeft)
        self.comboBox_PtnJCPDSBarThickness.setMaxCount(10)
        self.comboBox_PtnJCPDSBarThickness.setObjectName("comboBox_PtnJCPDSBarThickness")
        self.gridLayout_3.addWidget(self.comboBox_PtnJCPDSBarThickness, 1, 1, 1, 1)
        self.label_22 = QtWidgets.QLabel(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_22.sizePolicy().hasHeightForWidth())
        self.label_22.setSizePolicy(sizePolicy)
        self.label_22.setObjectName("label_22")
        self.gridLayout_3.addWidget(self.label_22, 1, 0, 1, 1)
        self.label_29 = QtWidgets.QLabel(self.groupBox_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_29.sizePolicy().hasHeightForWidth())
        self.label_29.setSizePolicy(sizePolicy)
        self.label_29.setObjectName("label_29")
        self.gridLayout_3.addWidget(self.label_29, 0, 0, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem4, 0, 2, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_3.addItem(spacerItem5, 1, 2, 1, 1)
        self.verticalLayout_33.addWidget(self.groupBox_27)
        self.groupBox_9 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_9.sizePolicy().hasHeightForWidth())
        self.groupBox_9.setSizePolicy(sizePolicy)
        self.groupBox_9.setFlat(False)
        self.groupBox_9.setObjectName("groupBox_9")
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout(self.groupBox_9)
        self.horizontalLayout_20.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        self.pushButton_NewJlist = QtWidgets.QPushButton(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_NewJlist.sizePolicy().hasHeightForWidth())
        self.pushButton_NewJlist.setSizePolicy(sizePolicy)
        self.pushButton_NewJlist.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_NewJlist.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_NewJlist.setFont(font)
        self.pushButton_NewJlist.setObjectName("pushButton_NewJlist")
        self.horizontalLayout_20.addWidget(self.pushButton_NewJlist)
        self.pushButton_ImportJlist = QtWidgets.QPushButton(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ImportJlist.sizePolicy().hasHeightForWidth())
        self.pushButton_ImportJlist.setSizePolicy(sizePolicy)
        self.pushButton_ImportJlist.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ImportJlist.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_ImportJlist.setFont(font)
        self.pushButton_ImportJlist.setObjectName("pushButton_ImportJlist")
        self.horizontalLayout_20.addWidget(self.pushButton_ImportJlist)
        self.pushButton_SaveJlist = QtWidgets.QPushButton(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SaveJlist.sizePolicy().hasHeightForWidth())
        self.pushButton_SaveJlist.setSizePolicy(sizePolicy)
        self.pushButton_SaveJlist.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SaveJlist.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_SaveJlist.setFont(font)
        self.pushButton_SaveJlist.setObjectName("pushButton_SaveJlist")
        self.horizontalLayout_20.addWidget(self.pushButton_SaveJlist)
        self.pushButton_ExportXLS = QtWidgets.QPushButton(self.groupBox_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ExportXLS.sizePolicy().hasHeightForWidth())
        self.pushButton_ExportXLS.setSizePolicy(sizePolicy)
        self.pushButton_ExportXLS.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ExportXLS.setMaximumSize(QtCore.QSize(60, 16777215))
        self.pushButton_ExportXLS.setObjectName("pushButton_ExportXLS")
        self.horizontalLayout_20.addWidget(self.pushButton_ExportXLS)
        self.verticalLayout_33.addWidget(self.groupBox_9)
        self.scrollArea_4.setWidget(self.scrollAreaWidgetContents_4)
        self.verticalLayout_27.addWidget(self.scrollArea_4)
        self.tabWidget1.addTab(self.tabWidgetPage2, "")
        self.verticalLayout_10.addWidget(self.tabWidget1)
        self.tabWidget.addTab(self.tab_JCPDSList2, "")
        self.tab_Plot = QtWidgets.QWidget()
        self.tab_Plot.setObjectName("tab_Plot")
        self.verticalLayout_44 = QtWidgets.QVBoxLayout(self.tab_Plot)
        self.verticalLayout_44.setObjectName("verticalLayout_44")
        self.scrollArea_10 = QtWidgets.QScrollArea(self.tab_Plot)
        self.scrollArea_10.setWidgetResizable(True)
        self.scrollArea_10.setObjectName("scrollArea_10")
        self.scrollAreaWidgetContents_13 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_13.setGeometry(QtCore.QRect(0, 0, 568, 637))
        self.scrollAreaWidgetContents_13.setObjectName("scrollAreaWidgetContents_13")
        self.verticalLayout_45 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_13)
        self.verticalLayout_45.setObjectName("verticalLayout_45")
        self.verticalLayout_45.addWidget(self.groupBox_34)
        self.verticalLayout_45.addWidget(self.groupBox_16)
        self.verticalLayout_45.addWidget(self.groupBox_24)
        self.verticalLayout_45.addWidget(self.groupBox_13)
        self.verticalLayout_45.addWidget(self.groupBox_20)
        self.verticalLayout_45.addWidget(self.groupBox_27)
        spacerItem24 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_45.addItem(spacerItem24)
        self.scrollArea_10.setWidget(self.scrollAreaWidgetContents_13)
        self.verticalLayout_44.addWidget(self.scrollArea_10)
        self.tabWidget.addTab(self.tab_Plot, "")
        self.tab_Bkgn = QtWidgets.QWidget()
        self.tab_Bkgn.setObjectName("tab_Bkgn")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.tab_Bkgn)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.tabWidget_5 = QtWidgets.QTabWidget(self.tab_Bkgn)
        self.tabWidget_5.setObjectName("tabWidget_5")
        self.tabWidget_5Page1 = QtWidgets.QWidget()
        self.tabWidget_5Page1.setObjectName("tabWidget_5Page1")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tabWidget_5Page1)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.scrollArea_5 = QtWidgets.QScrollArea(self.tabWidget_5Page1)
        self.scrollArea_5.setLineWidth(1)
        self.scrollArea_5.setWidgetResizable(True)
        self.scrollArea_5.setObjectName("scrollArea_5")
        self.scrollAreaWidgetContents_5 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_5.setGeometry(QtCore.QRect(0, 0, 568, 637))
        self.scrollAreaWidgetContents_5.setObjectName("scrollAreaWidgetContents_5")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_5)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.pushButton_UpdateBackground = QtWidgets.QPushButton(self.scrollAreaWidgetContents_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_UpdateBackground.sizePolicy().hasHeightForWidth())
        self.pushButton_UpdateBackground.setSizePolicy(sizePolicy)
        self.pushButton_UpdateBackground.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_UpdateBackground.setMaximumSize(QtCore.QSize(16777215, 100))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_UpdateBackground.setFont(font)
        self.pushButton_UpdateBackground.setObjectName("pushButton_UpdateBackground")
        self.verticalLayout_21.addWidget(self.pushButton_UpdateBackground)
        self.groupBox_4 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_4.sizePolicy().hasHeightForWidth())
        self.groupBox_4.setSizePolicy(sizePolicy)
        self.groupBox_4.setMinimumSize(QtCore.QSize(0, 25))
        self.groupBox_4.setFlat(False)
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_9.setObjectName("gridLayout_9")
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem6, 1, 1, 1, 1)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_9.addItem(spacerItem7, 2, 1, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setMinimumSize(QtCore.QSize(10, 0))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.gridLayout_9.addWidget(self.label_2, 1, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout_9.addWidget(self.label, 2, 0, 1, 1)
        self.doubleSpinBox_Background_ROI_max = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_Background_ROI_max.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_Background_ROI_max.setSizePolicy(sizePolicy)
        self.doubleSpinBox_Background_ROI_max.setMinimumSize(QtCore.QSize(75, 25))
        self.doubleSpinBox_Background_ROI_max.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_Background_ROI_max.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_Background_ROI_max.setDecimals(1)
        self.doubleSpinBox_Background_ROI_max.setMaximum(10000.0)
        self.doubleSpinBox_Background_ROI_max.setSingleStep(0.1)
        self.doubleSpinBox_Background_ROI_max.setProperty("value", 21.0)
        self.doubleSpinBox_Background_ROI_max.setObjectName("doubleSpinBox_Background_ROI_max")
        self.gridLayout_9.addWidget(self.doubleSpinBox_Background_ROI_max, 2, 2, 1, 1)
        self.doubleSpinBox_Background_ROI_min = QtWidgets.QDoubleSpinBox(self.groupBox_4)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.doubleSpinBox_Background_ROI_min.sizePolicy().hasHeightForWidth())
        self.doubleSpinBox_Background_ROI_min.setSizePolicy(sizePolicy)
        self.doubleSpinBox_Background_ROI_min.setMinimumSize(QtCore.QSize(75, 25))
        self.doubleSpinBox_Background_ROI_min.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.doubleSpinBox_Background_ROI_min.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_Background_ROI_min.setDecimals(1)
        self.doubleSpinBox_Background_ROI_min.setMaximum(10000.0)
        self.doubleSpinBox_Background_ROI_min.setSingleStep(0.1)
        self.doubleSpinBox_Background_ROI_min.setProperty("value", 6.0)
        self.doubleSpinBox_Background_ROI_min.setObjectName("doubleSpinBox_Background_ROI_min")
        self.gridLayout_9.addWidget(self.doubleSpinBox_Background_ROI_min, 1, 2, 1, 1)
        self.verticalLayout_21.addWidget(self.groupBox_4)
        self.groupBox_7 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_7.sizePolicy().hasHeightForWidth())
        self.groupBox_7.setSizePolicy(sizePolicy)
        self.groupBox_7.setMinimumSize(QtCore.QSize(0, 25))
        self.groupBox_7.setFlat(False)
        self.groupBox_7.setObjectName("groupBox_7")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_7)
        self.gridLayout_5.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.spinBox_BGParam2 = QtWidgets.QSpinBox(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_BGParam2.sizePolicy().hasHeightForWidth())
        self.spinBox_BGParam2.setSizePolicy(sizePolicy)
        self.spinBox_BGParam2.setMinimumSize(QtCore.QSize(75, 25))
        self.spinBox_BGParam2.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_BGParam2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_BGParam2.setMaximum(999)
        self.spinBox_BGParam2.setProperty("value", 20)
        self.spinBox_BGParam2.setObjectName("spinBox_BGParam2")
        self.gridLayout_5.addWidget(self.spinBox_BGParam2, 2, 2, 1, 1)
        self.spinBox_BGParam1 = QtWidgets.QSpinBox(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_BGParam1.sizePolicy().hasHeightForWidth())
        self.spinBox_BGParam1.setSizePolicy(sizePolicy)
        self.spinBox_BGParam1.setMinimumSize(QtCore.QSize(75, 25))
        self.spinBox_BGParam1.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_BGParam1.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_BGParam1.setMaximum(999)
        self.spinBox_BGParam1.setProperty("value", 10)
        self.spinBox_BGParam1.setObjectName("spinBox_BGParam1")
        self.gridLayout_5.addWidget(self.spinBox_BGParam1, 1, 2, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_5.sizePolicy().hasHeightForWidth())
        self.label_5.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label_5.setFont(font)
        self.label_5.setObjectName("label_5")
        self.gridLayout_5.addWidget(self.label_5, 2, 0, 1, 1)
        self.spinBox_BGParam0 = QtWidgets.QSpinBox(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_BGParam0.sizePolicy().hasHeightForWidth())
        self.spinBox_BGParam0.setSizePolicy(sizePolicy)
        self.spinBox_BGParam0.setMinimumSize(QtCore.QSize(75, 25))
        self.spinBox_BGParam0.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_BGParam0.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_BGParam0.setMaximum(999)
        self.spinBox_BGParam0.setProperty("value", 20)
        self.spinBox_BGParam0.setObjectName("spinBox_BGParam0")
        self.gridLayout_5.addWidget(self.spinBox_BGParam0, 0, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.gridLayout_5.addWidget(self.label_4, 0, 0, 1, 1)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem8, 2, 1, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem9, 0, 1, 1, 1)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_5.addItem(spacerItem10, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_6.sizePolicy().hasHeightForWidth())
        self.label_6.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.gridLayout_5.addWidget(self.label_6, 1, 0, 1, 1)
        self.verticalLayout_21.addWidget(self.groupBox_7)
        spacerItem11 = QtWidgets.QSpacerItem(20, 76, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_21.addItem(spacerItem11)
        self.pushButton_SaveBgSubCHI = QtWidgets.QPushButton(self.scrollAreaWidgetContents_5)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SaveBgSubCHI.sizePolicy().hasHeightForWidth())
        self.pushButton_SaveBgSubCHI.setSizePolicy(sizePolicy)
        self.pushButton_SaveBgSubCHI.setObjectName("pushButton_SaveBgSubCHI")
        self.verticalLayout_21.addWidget(self.pushButton_SaveBgSubCHI)
        self.scrollArea_5.setWidget(self.scrollAreaWidgetContents_5)
        self.verticalLayout_5.addWidget(self.scrollArea_5)
        self.tabWidget_5.addTab(self.tabWidget_5Page1, "")
        self.tabWidget_5Page2 = QtWidgets.QWidget()
        self.tabWidget_5Page2.setObjectName("tabWidget_5Page2")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self.tabWidget_5Page2)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.scrollArea_6 = QtWidgets.QScrollArea(self.tabWidget_5Page2)
        self.scrollArea_6.setWidgetResizable(True)
        self.scrollArea_6.setObjectName("scrollArea_6")
        self.scrollAreaWidgetContents_6 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_6.setGeometry(QtCore.QRect(0, 0, 360, 320))
        self.scrollAreaWidgetContents_6.setObjectName("scrollAreaWidgetContents_6")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_6)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.pushButton_ApplyWaterfallChange = QtWidgets.QPushButton(self.scrollAreaWidgetContents_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ApplyWaterfallChange.sizePolicy().hasHeightForWidth())
        self.pushButton_ApplyWaterfallChange.setSizePolicy(sizePolicy)
        self.pushButton_ApplyWaterfallChange.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ApplyWaterfallChange.setObjectName("pushButton_ApplyWaterfallChange")
        self.verticalLayout_35.addWidget(self.pushButton_ApplyWaterfallChange)
        self.groupBox_6 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_6.sizePolicy().hasHeightForWidth())
        self.groupBox_6.setSizePolicy(sizePolicy)
        self.groupBox_6.setTitle("")
        self.groupBox_6.setFlat(False)
        self.groupBox_6.setObjectName("groupBox_6")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.groupBox_6)
        self.verticalLayout_17.setContentsMargins(12, 12, 12, 12)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.checkBox_SetToBasePtnLambda = QtWidgets.QCheckBox(self.groupBox_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.checkBox_SetToBasePtnLambda.sizePolicy().hasHeightForWidth())
        self.checkBox_SetToBasePtnLambda.setSizePolicy(sizePolicy)
        self.checkBox_SetToBasePtnLambda.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_SetToBasePtnLambda.setChecked(True)
        self.checkBox_SetToBasePtnLambda.setObjectName("checkBox_SetToBasePtnLambda")
        self.verticalLayout_17.addWidget(self.checkBox_SetToBasePtnLambda)
        self.checkBox_IntNorm = QtWidgets.QCheckBox(self.groupBox_6)
        self.checkBox_IntNorm.setMinimumSize(QtCore.QSize(0, 25))
        self.checkBox_IntNorm.setChecked(True)
        self.checkBox_IntNorm.setObjectName("checkBox_IntNorm")
        self.verticalLayout_17.addWidget(self.checkBox_IntNorm)
        self.label_18 = QtWidgets.QLabel(self.groupBox_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_18.sizePolicy().hasHeightForWidth())
        self.label_18.setSizePolicy(sizePolicy)
        self.label_18.setMinimumSize(QtCore.QSize(0, 25))
        self.label_18.setAlignment(QtCore.Qt.AlignCenter)
        self.label_18.setObjectName("label_18")
        self.verticalLayout_17.addWidget(self.label_18)
        self.horizontalSlider_WaterfallGaps = QtWidgets.QSlider(self.groupBox_6)
        self.horizontalSlider_WaterfallGaps.setMinimumSize(QtCore.QSize(0, 25))
        self.horizontalSlider_WaterfallGaps.setMaximum(500)
        self.horizontalSlider_WaterfallGaps.setSingleStep(1)
        self.horizontalSlider_WaterfallGaps.setPageStep(10)
        self.horizontalSlider_WaterfallGaps.setSliderPosition(20)
        self.horizontalSlider_WaterfallGaps.setTickInterval(10)
        self.horizontalSlider_WaterfallGaps.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_WaterfallGaps.setObjectName("horizontalSlider_WaterfallGaps")
        self.verticalLayout_17.addWidget(self.horizontalSlider_WaterfallGaps)
        self.verticalLayout_35.addWidget(self.groupBox_6)
        self.frame_27 = QtWidgets.QFrame(self.scrollAreaWidgetContents_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_27.sizePolicy().hasHeightForWidth())
        self.frame_27.setSizePolicy(sizePolicy)
        self.frame_27.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_27.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame_27.setObjectName("frame_27")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.frame_27)
        self.gridLayout_12.setContentsMargins(9, 9, 9, 9)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.pushButton_AddPatterns = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_AddPatterns.sizePolicy().hasHeightForWidth())
        self.pushButton_AddPatterns.setSizePolicy(sizePolicy)
        self.pushButton_AddPatterns.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_AddPatterns.setMaximumSize(QtCore.QSize(32, 25))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_AddPatterns.setFont(font)
        self.pushButton_AddPatterns.setAutoRepeatDelay(300)
        self.pushButton_AddPatterns.setAutoRepeatInterval(100)
        self.pushButton_AddPatterns.setObjectName("pushButton_AddPatterns")
        self.gridLayout_12.addWidget(self.pushButton_AddPatterns, 0, 2, 1, 1)
        self.pushButton_DownPattern = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_DownPattern.sizePolicy().hasHeightForWidth())
        self.pushButton_DownPattern.setSizePolicy(sizePolicy)
        self.pushButton_DownPattern.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_DownPattern.setMaximumSize(QtCore.QSize(32, 25))
        self.pushButton_DownPattern.setObjectName("pushButton_DownPattern")
        self.gridLayout_12.addWidget(self.pushButton_DownPattern, 0, 5, 1, 1)
        self.pushButton_UpPattern = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_UpPattern.sizePolicy().hasHeightForWidth())
        self.pushButton_UpPattern.setSizePolicy(sizePolicy)
        self.pushButton_UpPattern.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_UpPattern.setMaximumSize(QtCore.QSize(32, 25))
        self.pushButton_UpPattern.setObjectName("pushButton_UpPattern")
        self.gridLayout_12.addWidget(self.pushButton_UpPattern, 0, 4, 1, 1)
        self.pushButton_RemovePatterns = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_RemovePatterns.sizePolicy().hasHeightForWidth())
        self.pushButton_RemovePatterns.setSizePolicy(sizePolicy)
        self.pushButton_RemovePatterns.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_RemovePatterns.setMaximumSize(QtCore.QSize(32, 25))
        self.pushButton_RemovePatterns.setObjectName("pushButton_RemovePatterns")
        self.gridLayout_12.addWidget(self.pushButton_RemovePatterns, 0, 3, 1, 1)
        self.pushButton_MakeBasePtn = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_MakeBasePtn.sizePolicy().hasHeightForWidth())
        self.pushButton_MakeBasePtn.setSizePolicy(sizePolicy)
        self.pushButton_MakeBasePtn.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_MakeBasePtn.setMaximumSize(QtCore.QSize(75, 16777215))
        self.pushButton_MakeBasePtn.setObjectName("pushButton_MakeBasePtn")
        self.gridLayout_12.addWidget(self.pushButton_MakeBasePtn, 0, 9, 1, 1)
        self.pushButton_CheckAllWaterfall = QtWidgets.QPushButton(self.frame_27)
        self.pushButton_CheckAllWaterfall.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_CheckAllWaterfall.setMaximumSize(QtCore.QSize(32, 25))
        self.pushButton_CheckAllWaterfall.setObjectName("pushButton_CheckAllWaterfall")
        self.gridLayout_12.addWidget(self.pushButton_CheckAllWaterfall, 0, 6, 1, 1)
        self.pushButton_CleanPatterns = QtWidgets.QPushButton(self.frame_27)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_CleanPatterns.sizePolicy().hasHeightForWidth())
        self.pushButton_CleanPatterns.setSizePolicy(sizePolicy)
        self.pushButton_CleanPatterns.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_CleanPatterns.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_CleanPatterns.setFont(font)
        self.pushButton_CleanPatterns.setObjectName("pushButton_CleanPatterns")
        self.gridLayout_12.addWidget(self.pushButton_CleanPatterns, 0, 8, 1, 1)
        self.pushButton_UncheckAllWaterfall = QtWidgets.QPushButton(self.frame_27)
        self.pushButton_UncheckAllWaterfall.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_UncheckAllWaterfall.setMaximumSize(QtCore.QSize(37, 25))
        self.pushButton_UncheckAllWaterfall.setObjectName("pushButton_UncheckAllWaterfall")
        self.gridLayout_12.addWidget(self.pushButton_UncheckAllWaterfall, 0, 7, 1, 1)
        self.verticalLayout_35.addWidget(self.frame_27)
        self.tableWidget_wfPatterns = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_6)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_wfPatterns.sizePolicy().hasHeightForWidth())
        self.tableWidget_wfPatterns.setSizePolicy(sizePolicy)
        self.tableWidget_wfPatterns.setMinimumSize(QtCore.QSize(0, 0))
        self.tableWidget_wfPatterns.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.tableWidget_wfPatterns.setFont(font)
        self.tableWidget_wfPatterns.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.tableWidget_wfPatterns.setObjectName("tableWidget_wfPatterns")
        self.tableWidget_wfPatterns.setColumnCount(0)
        self.tableWidget_wfPatterns.setRowCount(0)
        self.verticalLayout_35.addWidget(self.tableWidget_wfPatterns)
        self.scrollArea_6.setWidget(self.scrollAreaWidgetContents_6)
        self.verticalLayout_43.addWidget(self.scrollArea_6)
        self.tabWidget_5.addTab(self.tabWidget_5Page2, "")
        self.verticalLayout_8.addWidget(self.tabWidget_5)
        self.tabWidget.addTab(self.tab_Bkgn, "")
        self.tab_Cake1 = QtWidgets.QWidget()
        self.tab_Cake1.setObjectName("tab_Cake1")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_Cake1)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_Cake1)
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.tabWidget_2Page1 = QtWidgets.QWidget()
        self.tabWidget_2Page1.setObjectName("tabWidget_2Page1")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tabWidget_2Page1)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.scrollArea_7 = QtWidgets.QScrollArea(self.tabWidget_2Page1)
        self.scrollArea_7.setMinimumSize(QtCore.QSize(0, 0))
        self.scrollArea_7.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.scrollArea_7.setWidgetResizable(True)
        self.scrollArea_7.setObjectName("scrollArea_7")
        self.scrollAreaWidgetContents_7 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_7.setGeometry(QtCore.QRect(0, 0, 552, 637))
        self.scrollAreaWidgetContents_7.setObjectName("scrollAreaWidgetContents_7")
        self.verticalLayout_36 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_7)
        self.verticalLayout_36.setObjectName("verticalLayout_36")
        self.pushButton_ApplyCakeView = QtWidgets.QPushButton(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ApplyCakeView.sizePolicy().hasHeightForWidth())
        self.pushButton_ApplyCakeView.setSizePolicy(sizePolicy)
        self.pushButton_ApplyCakeView.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ApplyCakeView.setMaximumSize(QtCore.QSize(16777215, 100))
        self.pushButton_ApplyCakeView.setObjectName("pushButton_ApplyCakeView")
        self.verticalLayout_36.addWidget(self.pushButton_ApplyCakeView)
        self.groupBox_29 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_29.sizePolicy().hasHeightForWidth())
        self.groupBox_29.setSizePolicy(sizePolicy)
        self.groupBox_29.setMinimumSize(QtCore.QSize(0, 180))
        self.groupBox_29.setMaximumSize(QtCore.QSize(16777215, 250))
        self.groupBox_29.setFlat(False)
        self.groupBox_29.setObjectName("groupBox_29")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.groupBox_29)
        self.verticalLayout_11.setContentsMargins(12, 12, 12, 12)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.frame_8 = QtWidgets.QFrame(self.groupBox_29)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_8.sizePolicy().hasHeightForWidth())
        self.frame_8.setSizePolicy(sizePolicy)
        self.frame_8.setMinimumSize(QtCore.QSize(0, 25))
        self.frame_8.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.frame_8.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame_8.setObjectName("frame_8")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.frame_8)
        self.horizontalLayout_8.setContentsMargins(-1, 3, -1, 3)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.spinBox_MaxCakeScale = QtWidgets.QSpinBox(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_MaxCakeScale.sizePolicy().hasHeightForWidth())
        self.spinBox_MaxCakeScale.setSizePolicy(sizePolicy)
        self.spinBox_MaxCakeScale.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBox_MaxCakeScale.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.spinBox_MaxCakeScale.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_MaxCakeScale.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_MaxCakeScale.setButtonSymbols(QtWidgets.QAbstractSpinBox.NoButtons)
        self.spinBox_MaxCakeScale.setMaximum(10000000)
        self.spinBox_MaxCakeScale.setProperty("value", 100000)
        self.spinBox_MaxCakeScale.setObjectName("spinBox_MaxCakeScale")
        self.horizontalLayout_8.addWidget(self.spinBox_MaxCakeScale)
        self.pushButton_ResetCakeScale = QtWidgets.QPushButton(self.frame_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ResetCakeScale.sizePolicy().hasHeightForWidth())
        self.pushButton_ResetCakeScale.setSizePolicy(sizePolicy)
        self.pushButton_ResetCakeScale.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ResetCakeScale.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.pushButton_ResetCakeScale.setAutoDefault(False)
        self.pushButton_ResetCakeScale.setDefault(False)
        self.pushButton_ResetCakeScale.setFlat(False)
        self.pushButton_ResetCakeScale.setObjectName("pushButton_ResetCakeScale")
        self.horizontalLayout_8.addWidget(self.pushButton_ResetCakeScale)
        self.verticalLayout_11.addWidget(self.frame_8)
        self.label_8 = QtWidgets.QLabel(self.groupBox_29)
        self.label_8.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.label_8.setAlignment(QtCore.Qt.AlignCenter)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_11.addWidget(self.label_8)
        self.horizontalSlider_VMin = QtWidgets.QSlider(self.groupBox_29)
        self.horizontalSlider_VMin.setMinimumSize(QtCore.QSize(0, 25))
        self.horizontalSlider_VMin.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.horizontalSlider_VMin.setMinimum(1)
        self.horizontalSlider_VMin.setMaximum(1000)
        self.horizontalSlider_VMin.setPageStep(1000)
        self.horizontalSlider_VMin.setProperty("value", 1)
        self.horizontalSlider_VMin.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_VMin.setInvertedAppearance(False)
        self.horizontalSlider_VMin.setInvertedControls(False)
        self.horizontalSlider_VMin.setTickPosition(QtWidgets.QSlider.NoTicks)
        self.horizontalSlider_VMin.setTickInterval(1)
        self.horizontalSlider_VMin.setObjectName("horizontalSlider_VMin")
        self.verticalLayout_11.addWidget(self.horizontalSlider_VMin)
        self.label_9 = QtWidgets.QLabel(self.groupBox_29)
        self.label_9.setAlignment(QtCore.Qt.AlignHCenter|QtCore.Qt.AlignTop)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_11.addWidget(self.label_9)
        self.horizontalSlider_VMax = QtWidgets.QSlider(self.groupBox_29)
        self.horizontalSlider_VMax.setMinimumSize(QtCore.QSize(0, 25))
        self.horizontalSlider_VMax.setMinimum(1)
        self.horizontalSlider_VMax.setMaximum(1000)
        self.horizontalSlider_VMax.setPageStep(1000)
        self.horizontalSlider_VMax.setProperty("value", 150)
        self.horizontalSlider_VMax.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_VMax.setTickPosition(QtWidgets.QSlider.NoTicks)
        self.horizontalSlider_VMax.setObjectName("horizontalSlider_VMax")
        self.verticalLayout_11.addWidget(self.horizontalSlider_VMax)
        self.label_19 = QtWidgets.QLabel(self.groupBox_29)
        self.label_19.setAlignment(QtCore.Qt.AlignCenter)
        self.label_19.setObjectName("label_19")
        self.verticalLayout_11.addWidget(self.label_19)
        self.horizontalSlider_MaxScaleBars = QtWidgets.QSlider(self.groupBox_29)
        self.horizontalSlider_MaxScaleBars.setMinimumSize(QtCore.QSize(0, 25))
        self.horizontalSlider_MaxScaleBars.setMinimum(0)
        self.horizontalSlider_MaxScaleBars.setMaximum(5)
        self.horizontalSlider_MaxScaleBars.setPageStep(5)
        self.horizontalSlider_MaxScaleBars.setProperty("value", 2)
        self.horizontalSlider_MaxScaleBars.setSliderPosition(2)
        self.horizontalSlider_MaxScaleBars.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_MaxScaleBars.setInvertedAppearance(True)
        self.horizontalSlider_MaxScaleBars.setTickPosition(QtWidgets.QSlider.TicksBothSides)
        self.horizontalSlider_MaxScaleBars.setTickInterval(1)
        self.horizontalSlider_MaxScaleBars.setObjectName("horizontalSlider_MaxScaleBars")
        self.verticalLayout_11.addWidget(self.horizontalSlider_MaxScaleBars)
        self.verticalLayout_36.addWidget(self.groupBox_29)
        self.groupBox_5 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_5.sizePolicy().hasHeightForWidth())
        self.groupBox_5.setSizePolicy(sizePolicy)
        self.groupBox_5.setTitle("")
        self.groupBox_5.setFlat(False)
        self.groupBox_5.setObjectName("groupBox_5")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.groupBox_5)
        self.horizontalLayout.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_20 = QtWidgets.QLabel(self.groupBox_5)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout.addWidget(self.label_20)
        self.horizontalSlider_CakeAxisSize = QtWidgets.QSlider(self.groupBox_5)
        self.horizontalSlider_CakeAxisSize.setMinimumSize(QtCore.QSize(0, 25))
        self.horizontalSlider_CakeAxisSize.setMinimum(1)
        self.horizontalSlider_CakeAxisSize.setMaximum(90)
        self.horizontalSlider_CakeAxisSize.setPageStep(1)
        self.horizontalSlider_CakeAxisSize.setProperty("value", 25)
        self.horizontalSlider_CakeAxisSize.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_CakeAxisSize.setObjectName("horizontalSlider_CakeAxisSize")
        self.horizontalLayout.addWidget(self.horizontalSlider_CakeAxisSize)
        self.verticalLayout_36.addWidget(self.groupBox_5)
        self.groupBox_23 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_23.sizePolicy().hasHeightForWidth())
        self.groupBox_23.setSizePolicy(sizePolicy)
        self.groupBox_23.setTitle("")
        self.groupBox_23.setFlat(False)
        self.groupBox_23.setObjectName("groupBox_23")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_23)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_7 = QtWidgets.QLabel(self.groupBox_23)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_7.sizePolicy().hasHeightForWidth())
        self.label_7.setSizePolicy(sizePolicy)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_5.addWidget(self.label_7)
        self.spinBox_AziShift = QtWidgets.QSpinBox(self.groupBox_23)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spinBox_AziShift.sizePolicy().hasHeightForWidth())
        self.spinBox_AziShift.setSizePolicy(sizePolicy)
        self.spinBox_AziShift.setMinimumSize(QtCore.QSize(80, 25))
        self.spinBox_AziShift.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_AziShift.setMaximum(359)
        self.spinBox_AziShift.setSingleStep(5)
        self.spinBox_AziShift.setObjectName("spinBox_AziShift")
        self.horizontalLayout_5.addWidget(self.spinBox_AziShift)
        self.verticalLayout_36.addWidget(self.groupBox_23)
        self.groupBox_11 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_11.sizePolicy().hasHeightForWidth())
        self.groupBox_11.setSizePolicy(sizePolicy)
        self.groupBox_11.setTitle("")
        self.groupBox_11.setFlat(False)
        self.groupBox_11.setObjectName("groupBox_11")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_11)
        self.gridLayout_4.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.lineEdit_PONI = QtWidgets.QLineEdit(self.groupBox_11)
        self.lineEdit_PONI.setMinimumSize(QtCore.QSize(0, 25))
        self.lineEdit_PONI.setObjectName("lineEdit_PONI")
        self.gridLayout_4.addWidget(self.lineEdit_PONI, 1, 1, 1, 1)
        self.pushButton_GetPONI = QtWidgets.QPushButton(self.groupBox_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_GetPONI.sizePolicy().hasHeightForWidth())
        self.pushButton_GetPONI.setSizePolicy(sizePolicy)
        self.pushButton_GetPONI.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton_GetPONI.setMaximumSize(QtCore.QSize(40, 16777215))
        self.pushButton_GetPONI.setObjectName("pushButton_GetPONI")
        self.gridLayout_4.addWidget(self.pushButton_GetPONI, 1, 2, 1, 1)
        self.label_32 = QtWidgets.QLabel(self.groupBox_11)
        self.label_32.setObjectName("label_32")
        self.gridLayout_4.addWidget(self.label_32, 1, 0, 1, 1)
        self.verticalLayout_36.addWidget(self.groupBox_11)
        self.groupBox_14 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_7)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_14.sizePolicy().hasHeightForWidth())
        self.groupBox_14.setSizePolicy(sizePolicy)
        self.groupBox_14.setTitle("")
        self.groupBox_14.setFlat(False)
        self.groupBox_14.setObjectName("groupBox_14")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.groupBox_14)
        self.horizontalLayout_9.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_33 = QtWidgets.QLabel(self.groupBox_14)
        self.label_33.setObjectName("label_33")
        self.horizontalLayout_9.addWidget(self.label_33)
        self.textEdit_DiffractionImageFilename = QtWidgets.QTextEdit(self.groupBox_14)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textEdit_DiffractionImageFilename.sizePolicy().hasHeightForWidth())
        self.textEdit_DiffractionImageFilename.setSizePolicy(sizePolicy)
        self.textEdit_DiffractionImageFilename.setMinimumSize(QtCore.QSize(0, 25))
        self.textEdit_DiffractionImageFilename.setMaximumSize(QtCore.QSize(16777215, 35))
        self.textEdit_DiffractionImageFilename.setReadOnly(True)
        self.textEdit_DiffractionImageFilename.setObjectName("textEdit_DiffractionImageFilename")
        self.horizontalLayout_9.addWidget(self.textEdit_DiffractionImageFilename)
        self.verticalLayout_36.addWidget(self.groupBox_14)
        spacerItem12 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_36.addItem(spacerItem12)
        self.scrollArea_7.setWidget(self.scrollAreaWidgetContents_7)
        self.verticalLayout_4.addWidget(self.scrollArea_7)
        self.tabWidget_2.addTab(self.tabWidget_2Page1, "")
        self.tabWidget_2Page2 = QtWidgets.QWidget()
        self.tabWidget_2Page2.setObjectName("tabWidget_2Page2")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.tabWidget_2Page2)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.scrollArea_8 = QtWidgets.QScrollArea(self.tabWidget_2Page2)
        self.scrollArea_8.setWidgetResizable(True)
        self.scrollArea_8.setObjectName("scrollArea_8")
        self.scrollAreaWidgetContents_8 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_8.setGeometry(QtCore.QRect(0, 0, 568, 637))
        self.scrollAreaWidgetContents_8.setObjectName("scrollAreaWidgetContents_8")
        self.verticalLayout_37 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_8)
        self.verticalLayout_37.setObjectName("verticalLayout_37")
        self.groupBox_30 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_30.sizePolicy().hasHeightForWidth())
        self.groupBox_30.setSizePolicy(sizePolicy)
        self.groupBox_30.setTitle("")
        self.groupBox_30.setFlat(False)
        self.groupBox_30.setObjectName("groupBox_30")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.groupBox_30)
        self.horizontalLayout_16.setContentsMargins(12, 12, 12, 12)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.label_34 = QtWidgets.QLabel(self.groupBox_30)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_34.sizePolicy().hasHeightForWidth())
        self.label_34.setSizePolicy(sizePolicy)
        self.label_34.setObjectName("label_34")
        self.horizontalLayout_16.addWidget(self.label_34)
        self.label_11 = QtWidgets.QLabel(self.groupBox_30)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_11.sizePolicy().hasHeightForWidth())
        self.label_11.setSizePolicy(sizePolicy)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_16.addWidget(self.label_11)
        self.spinBox_MaskMin = QtWidgets.QSpinBox(self.groupBox_30)
        self.spinBox_MaskMin.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBox_MaskMin.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_MaskMin.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_MaskMin.setMinimum(-1000000)
        self.spinBox_MaskMin.setMaximum(10000000)
        self.spinBox_MaskMin.setObjectName("spinBox_MaskMin")
        self.horizontalLayout_16.addWidget(self.spinBox_MaskMin)
        self.label_10 = QtWidgets.QLabel(self.groupBox_30)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_10.sizePolicy().hasHeightForWidth())
        self.label_10.setSizePolicy(sizePolicy)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_16.addWidget(self.label_10)
        self.spinBox_MaskMax = QtWidgets.QSpinBox(self.groupBox_30)
        self.spinBox_MaskMax.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBox_MaskMax.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.spinBox_MaskMax.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_MaskMax.setMinimum(-1000)
        self.spinBox_MaskMax.setMaximum(10000000)
        self.spinBox_MaskMax.setProperty("value", 10000000)
        self.spinBox_MaskMax.setObjectName("spinBox_MaskMax")
        self.horizontalLayout_16.addWidget(self.spinBox_MaskMax)
        self.pushButton_MaskReset = QtWidgets.QPushButton(self.groupBox_30)
        self.pushButton_MaskReset.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_MaskReset.setObjectName("pushButton_MaskReset")
        self.horizontalLayout_16.addWidget(self.pushButton_MaskReset)
        self.pushButton_ApplyMask = QtWidgets.QPushButton(self.groupBox_30)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ApplyMask.sizePolicy().hasHeightForWidth())
        self.pushButton_ApplyMask.setSizePolicy(sizePolicy)
        self.pushButton_ApplyMask.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ApplyMask.setCheckable(True)
        self.pushButton_ApplyMask.setObjectName("pushButton_ApplyMask")
        self.horizontalLayout_16.addWidget(self.pushButton_ApplyMask)
        self.verticalLayout_37.addWidget(self.groupBox_30)
        self.groupBox_19 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_8)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_19.sizePolicy().hasHeightForWidth())
        self.groupBox_19.setSizePolicy(sizePolicy)
        self.groupBox_19.setTitle("")
        self.groupBox_19.setFlat(False)
        self.groupBox_19.setObjectName("groupBox_19")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.groupBox_19)
        self.gridLayout_16.setContentsMargins(-1, 12, -1, 12)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.pushButton_AddAzi = QtWidgets.QPushButton(self.groupBox_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_AddAzi.sizePolicy().hasHeightForWidth())
        self.pushButton_AddAzi.setSizePolicy(sizePolicy)
        self.pushButton_AddAzi.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_AddAzi.setObjectName("pushButton_AddAzi")
        self.gridLayout_16.addWidget(self.pushButton_AddAzi, 0, 0, 1, 1)
        self.pushButton_ClearAziList = QtWidgets.QPushButton(self.groupBox_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ClearAziList.sizePolicy().hasHeightForWidth())
        self.pushButton_ClearAziList.setSizePolicy(sizePolicy)
        self.pushButton_ClearAziList.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_ClearAziList.setObjectName("pushButton_ClearAziList")
        self.gridLayout_16.addWidget(self.pushButton_ClearAziList, 0, 2, 1, 1)
        self.pushButton_LoadCakeMarkerFile = QtWidgets.QPushButton(self.groupBox_19)
        self.pushButton_LoadCakeMarkerFile.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_LoadCakeMarkerFile.setObjectName("pushButton_LoadCakeMarkerFile")
        self.gridLayout_16.addWidget(self.pushButton_LoadCakeMarkerFile, 0, 4, 1, 1)
        self.pushButton_RemoveAzi = QtWidgets.QPushButton(self.groupBox_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_RemoveAzi.sizePolicy().hasHeightForWidth())
        self.pushButton_RemoveAzi.setSizePolicy(sizePolicy)
        self.pushButton_RemoveAzi.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_RemoveAzi.setObjectName("pushButton_RemoveAzi")
        self.gridLayout_16.addWidget(self.pushButton_RemoveAzi, 1, 0, 1, 1)
        self.pushButton_InvertCakeBoxes = QtWidgets.QPushButton(self.groupBox_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_InvertCakeBoxes.sizePolicy().hasHeightForWidth())
        self.pushButton_InvertCakeBoxes.setSizePolicy(sizePolicy)
        self.pushButton_InvertCakeBoxes.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_InvertCakeBoxes.setObjectName("pushButton_InvertCakeBoxes")
        self.gridLayout_16.addWidget(self.pushButton_InvertCakeBoxes, 1, 2, 1, 1)
        self.pushButton_SaveCakeMarkerFile = QtWidgets.QPushButton(self.groupBox_19)
        self.pushButton_SaveCakeMarkerFile.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_SaveCakeMarkerFile.setObjectName("pushButton_SaveCakeMarkerFile")
        self.gridLayout_16.addWidget(self.pushButton_SaveCakeMarkerFile, 1, 4, 1, 1)
        self.pushButton_IntegrateCake = QtWidgets.QPushButton(self.groupBox_19)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_IntegrateCake.sizePolicy().hasHeightForWidth())
        self.pushButton_IntegrateCake.setSizePolicy(sizePolicy)
        self.pushButton_IntegrateCake.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_IntegrateCake.setObjectName("pushButton_IntegrateCake")
        self.gridLayout_16.addWidget(self.pushButton_IntegrateCake, 1, 5, 1, 1)
        self.pushButton_HighlightSelectedMarker = QtWidgets.QPushButton(self.groupBox_19)
        self.pushButton_HighlightSelectedMarker.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_HighlightSelectedMarker.setObjectName("pushButton_HighlightSelectedMarker")
        self.gridLayout_16.addWidget(self.pushButton_HighlightSelectedMarker, 0, 5, 1, 1)
        self.verticalLayout_37.addWidget(self.groupBox_19)
        self.tableWidget_DiffImgAzi = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_8)
        self.tableWidget_DiffImgAzi.setRowCount(0)
        self.tableWidget_DiffImgAzi.setColumnCount(5)
        self.tableWidget_DiffImgAzi.setObjectName("tableWidget_DiffImgAzi")
        self.verticalLayout_37.addWidget(self.tableWidget_DiffImgAzi)
        self.scrollArea_8.setWidget(self.scrollAreaWidgetContents_8)
        self.verticalLayout_28.addWidget(self.scrollArea_8)
        self.tabWidget_2.addTab(self.tabWidget_2Page2, "")
        self.verticalLayout_3.addWidget(self.tabWidget_2)
        self.tabWidget.addTab(self.tab_Cake1, "")
        self.tab_PkFt = QtWidgets.QWidget()
        self.tab_PkFt.setObjectName("tab_PkFt")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.tab_PkFt)
        self.verticalLayout_14.setContentsMargins(12, 12, 12, -1)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.tabWidget_4 = QtWidgets.QTabWidget(self.tab_PkFt)
        self.tabWidget_4.setObjectName("tabWidget_4")
        self.tabWidget_4Page1 = QtWidgets.QWidget()
        self.tabWidget_4Page1.setObjectName("tabWidget_4Page1")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.tabWidget_4Page1)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.tabWidget_PeakFit = QtWidgets.QTabWidget(self.tabWidget_4Page1)
        self.tabWidget_PeakFit.setObjectName("tabWidget_PeakFit")
        self.tab_PeakFitSection = QtWidgets.QWidget()
        self.tab_PeakFitSection.setObjectName("tab_PeakFitSection")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.tab_PeakFitSection)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.scrollArea_10 = QtWidgets.QScrollArea(self.tab_PeakFitSection)
        self.scrollArea_10.setWidgetResizable(True)
        self.scrollArea_10.setObjectName("scrollArea_10")
        self.scrollAreaWidgetContents_10 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_10.setGeometry(QtCore.QRect(0, 0, 345, 186))
        self.scrollAreaWidgetContents_10.setObjectName("scrollAreaWidgetContents_10")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_10)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.frame_28 = QtWidgets.QFrame(self.scrollAreaWidgetContents_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_28.sizePolicy().hasHeightForWidth())
        self.frame_28.setSizePolicy(sizePolicy)
        self.frame_28.setObjectName("frame_28")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.frame_28)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.pushButton_PkFtSectionRemove = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PkFtSectionRemove.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PkFtSectionRemove.setObjectName("pushButton_PkFtSectionRemove")
        self.gridLayout_20.addWidget(self.pushButton_PkFtSectionRemove, 0, 0, 1, 1)
        self.pushButton_PkFtSectionSetToCurrent = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PkFtSectionSetToCurrent.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PkFtSectionSetToCurrent.setObjectName("pushButton_PkFtSectionSetToCurrent")
        self.gridLayout_20.addWidget(self.pushButton_PkFtSectionSetToCurrent, 0, 1, 1, 1)
        self.pushButton_PlotSelectedPkFtResults = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PlotSelectedPkFtResults.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PlotSelectedPkFtResults.setObjectName("pushButton_PlotSelectedPkFtResults")
        self.gridLayout_20.addWidget(self.pushButton_PlotSelectedPkFtResults, 0, 2, 1, 1)
        self.pushButton_PkFtSectionClear = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PkFtSectionClear.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PkFtSectionClear.setObjectName("pushButton_PkFtSectionClear")
        self.gridLayout_20.addWidget(self.pushButton_PkFtSectionClear, 1, 0, 1, 1)
        self.pushButton_PkFtSectionImport = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PkFtSectionImport.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PkFtSectionImport.setObjectName("pushButton_PkFtSectionImport")
        self.gridLayout_20.addWidget(self.pushButton_PkFtSectionImport, 1, 1, 1, 1)
        self.pushButton_PkFtSectionSavetoXLS = QtWidgets.QPushButton(self.frame_28)
        self.pushButton_PkFtSectionSavetoXLS.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PkFtSectionSavetoXLS.setObjectName("pushButton_PkFtSectionSavetoXLS")
        self.gridLayout_20.addWidget(self.pushButton_PkFtSectionSavetoXLS, 1, 2, 1, 1)
        self.verticalLayout_39.addWidget(self.frame_28)
        self.tableWidget_PkFtSections = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_10)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_PkFtSections.sizePolicy().hasHeightForWidth())
        self.tableWidget_PkFtSections.setSizePolicy(sizePolicy)
        self.tableWidget_PkFtSections.setObjectName("tableWidget_PkFtSections")
        self.tableWidget_PkFtSections.setColumnCount(0)
        self.tableWidget_PkFtSections.setRowCount(0)
        self.verticalLayout_39.addWidget(self.tableWidget_PkFtSections)
        self.scrollArea_10.setWidget(self.scrollAreaWidgetContents_10)
        self.verticalLayout_15.addWidget(self.scrollArea_10)
        self.tabWidget_PeakFit.addTab(self.tab_PeakFitSection, "")
        self.tab_PeakFitPeaks = QtWidgets.QWidget()
        self.tab_PeakFitPeaks.setObjectName("tab_PeakFitPeaks")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.tab_PeakFitPeaks)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.scrollArea_11 = QtWidgets.QScrollArea(self.tab_PeakFitPeaks)
        self.scrollArea_11.setWidgetResizable(True)
        self.scrollArea_11.setObjectName("scrollArea_11")
        self.scrollAreaWidgetContents_11 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_11.setGeometry(QtCore.QRect(0, 0, 522, 582))
        self.scrollAreaWidgetContents_11.setObjectName("scrollAreaWidgetContents_11")
        self.verticalLayout_40 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_11)
        self.verticalLayout_40.setObjectName("verticalLayout_40")
        self.groupBox_35 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_35.sizePolicy().hasHeightForWidth())
        self.groupBox_35.setSizePolicy(sizePolicy)
        self.groupBox_35.setFlat(False)
        self.groupBox_35.setObjectName("groupBox_35")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.groupBox_35)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.pushButton_ConductFitting = QtWidgets.QPushButton(self.groupBox_35)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_ConductFitting.sizePolicy().hasHeightForWidth())
        self.pushButton_ConductFitting.setSizePolicy(sizePolicy)
        self.pushButton_ConductFitting.setObjectName("pushButton_ConductFitting")
        self.gridLayout_17.addWidget(self.pushButton_ConductFitting, 0, 3, 1, 1)
        self.pushButton_SetFitSection = QtWidgets.QPushButton(self.groupBox_35)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_SetFitSection.sizePolicy().hasHeightForWidth())
        self.pushButton_SetFitSection.setSizePolicy(sizePolicy)
        self.pushButton_SetFitSection.setObjectName("pushButton_SetFitSection")
        self.gridLayout_17.addWidget(self.pushButton_SetFitSection, 0, 0, 1, 1)
        self.pushButton_ZoomToSection = QtWidgets.QPushButton(self.groupBox_35)
        self.pushButton_ZoomToSection.setObjectName("pushButton_ZoomToSection")
        self.gridLayout_17.addWidget(self.pushButton_ZoomToSection, 0, 1, 1, 1)
        self.pushButton_PkSave = QtWidgets.QPushButton(self.groupBox_35)
        self.pushButton_PkSave.setObjectName("pushButton_PkSave")
        self.gridLayout_17.addWidget(self.pushButton_PkSave, 1, 0, 1, 1)
        self.pushButton_ClearSection = QtWidgets.QPushButton(self.groupBox_35)
        self.pushButton_ClearSection.setObjectName("pushButton_ClearSection")
        self.gridLayout_17.addWidget(self.pushButton_ClearSection, 1, 1, 1, 1)
        self.verticalLayout_40.addWidget(self.groupBox_35)
        self.groupBox_32 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_32.sizePolicy().hasHeightForWidth())
        self.groupBox_32.setSizePolicy(sizePolicy)
        self.groupBox_32.setFlat(False)
        self.groupBox_32.setObjectName("groupBox_32")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.groupBox_32)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.spinBox_PeaksFromJlistIntensity = QtWidgets.QSpinBox(self.groupBox_32)
        self.spinBox_PeaksFromJlistIntensity.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBox_PeaksFromJlistIntensity.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_PeaksFromJlistIntensity.setObjectName("spinBox_PeaksFromJlistIntensity")
        self.gridLayout_18.addWidget(self.spinBox_PeaksFromJlistIntensity, 2, 3, 1, 1)
        self.pushButton_AddRemoveFromMouse = QtWidgets.QPushButton(self.groupBox_32)
        self.pushButton_AddRemoveFromMouse.setCheckable(True)
        self.pushButton_AddRemoveFromMouse.setObjectName("pushButton_AddRemoveFromMouse")
        self.gridLayout_18.addWidget(self.pushButton_AddRemoveFromMouse, 1, 0, 1, 1)
        self.label_16 = QtWidgets.QLabel(self.groupBox_32)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_16.sizePolicy().hasHeightForWidth())
        self.label_16.setSizePolicy(sizePolicy)
        self.label_16.setObjectName("label_16")
        self.gridLayout_18.addWidget(self.label_16, 2, 2, 1, 1)
        self.pushButton_AddRemoveFromJlist = QtWidgets.QPushButton(self.groupBox_32)
        self.pushButton_AddRemoveFromJlist.setObjectName("pushButton_AddRemoveFromJlist")
        self.gridLayout_18.addWidget(self.pushButton_AddRemoveFromJlist, 2, 0, 1, 1)
        self.verticalLayout_40.addWidget(self.groupBox_32)
        self.tableWidget_PkParams = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_11)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_PkParams.sizePolicy().hasHeightForWidth())
        self.tableWidget_PkParams.setSizePolicy(sizePolicy)
        self.tableWidget_PkParams.setObjectName("tableWidget_PkParams")
        self.tableWidget_PkParams.setColumnCount(0)
        self.tableWidget_PkParams.setRowCount(0)
        self.verticalLayout_40.addWidget(self.tableWidget_PkParams)
        self.scrollArea_11.setWidget(self.scrollAreaWidgetContents_11)
        self.verticalLayout_16.addWidget(self.scrollArea_11)
        self.tabWidget_PeakFit.addTab(self.tab_PeakFitPeaks, "")
        self.tab_PeakFitConfig = QtWidgets.QWidget()
        self.tab_PeakFitConfig.setObjectName("tab_PeakFitConfig")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.tab_PeakFitConfig)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.scrollArea_12 = QtWidgets.QScrollArea(self.tab_PeakFitConfig)
        self.scrollArea_12.setWidgetResizable(True)
        self.scrollArea_12.setObjectName("scrollArea_12")
        self.scrollAreaWidgetContents_12 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_12.setGeometry(QtCore.QRect(0, 0, 192, 435))
        self.scrollAreaWidgetContents_12.setObjectName("scrollAreaWidgetContents_12")
        self.verticalLayout_41 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_12)
        self.verticalLayout_41.setObjectName("verticalLayout_41")
        self.groupBox_25 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_12)
        self.groupBox_25.setFlat(False)
        self.groupBox_25.setObjectName("groupBox_25")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.groupBox_25)
        self.gridLayout_19.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.doubleSpinBox_PeakCenterRange = QtWidgets.QDoubleSpinBox(self.groupBox_25)
        self.doubleSpinBox_PeakCenterRange.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_PeakCenterRange.setMaximumSize(QtCore.QSize(80, 16777215))
        self.doubleSpinBox_PeakCenterRange.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_PeakCenterRange.setDecimals(2)
        self.doubleSpinBox_PeakCenterRange.setMaximum(1000.0)
        self.doubleSpinBox_PeakCenterRange.setSingleStep(1.0)
        self.doubleSpinBox_PeakCenterRange.setProperty("value", 50.0)
        self.doubleSpinBox_PeakCenterRange.setObjectName("doubleSpinBox_PeakCenterRange")
        self.gridLayout_19.addWidget(self.doubleSpinBox_PeakCenterRange, 0, 1, 1, 1)
        self.label_13 = QtWidgets.QLabel(self.groupBox_25)
        self.label_13.setObjectName("label_13")
        self.gridLayout_19.addWidget(self.label_13, 1, 0, 1, 1)
        self.doubleSpinBox_InitialFWHM = QtWidgets.QDoubleSpinBox(self.groupBox_25)
        self.doubleSpinBox_InitialFWHM.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_InitialFWHM.setMaximumSize(QtCore.QSize(80, 16777215))
        self.doubleSpinBox_InitialFWHM.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_InitialFWHM.setDecimals(3)
        self.doubleSpinBox_InitialFWHM.setMaximum(1000.0)
        self.doubleSpinBox_InitialFWHM.setSingleStep(1.0)
        self.doubleSpinBox_InitialFWHM.setProperty("value", 50.0)
        self.doubleSpinBox_InitialFWHM.setObjectName("doubleSpinBox_InitialFWHM")
        self.gridLayout_19.addWidget(self.doubleSpinBox_InitialFWHM, 1, 1, 1, 1)
        self.label_31 = QtWidgets.QLabel(self.groupBox_25)
        self.label_31.setObjectName("label_31")
        self.gridLayout_19.addWidget(self.label_31, 2, 0, 1, 1)
        self.doubleSpinBox_MaxFWHM = QtWidgets.QDoubleSpinBox(self.groupBox_25)
        self.doubleSpinBox_MaxFWHM.setMinimumSize(QtCore.QSize(0, 25))
        self.doubleSpinBox_MaxFWHM.setMaximumSize(QtCore.QSize(80, 16777215))
        self.doubleSpinBox_MaxFWHM.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.doubleSpinBox_MaxFWHM.setDecimals(3)
        self.doubleSpinBox_MaxFWHM.setMaximum(5000.0)
        self.doubleSpinBox_MaxFWHM.setSingleStep(1.0)
        self.doubleSpinBox_MaxFWHM.setProperty("value", 200.0)
        self.doubleSpinBox_MaxFWHM.setObjectName("doubleSpinBox_MaxFWHM")
        self.gridLayout_19.addWidget(self.doubleSpinBox_MaxFWHM, 2, 1, 1, 1)
        self.label_12 = QtWidgets.QLabel(self.groupBox_25)
        self.label_12.setObjectName("label_12")
        self.gridLayout_19.addWidget(self.label_12, 0, 0, 1, 1)
        self.verticalLayout_41.addWidget(self.groupBox_25)
        self.tableWidget_PeakConstraints = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_12)
        self.tableWidget_PeakConstraints.setObjectName("tableWidget_PeakConstraints")
        self.tableWidget_PeakConstraints.setColumnCount(0)
        self.tableWidget_PeakConstraints.setRowCount(0)
        self.verticalLayout_41.addWidget(self.tableWidget_PeakConstraints)
        self.groupBox_31 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_12)
        self.groupBox_31.setFlat(False)
        self.groupBox_31.setObjectName("groupBox_31")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.groupBox_31)
        self.horizontalLayout_3.setContentsMargins(-1, 12, -1, 12)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_14 = QtWidgets.QLabel(self.groupBox_31)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_3.addWidget(self.label_14)
        self.spinBox_BGPolyOrder = QtWidgets.QSpinBox(self.groupBox_31)
        self.spinBox_BGPolyOrder.setMinimumSize(QtCore.QSize(0, 25))
        self.spinBox_BGPolyOrder.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.spinBox_BGPolyOrder.setProperty("value", 0)
        self.spinBox_BGPolyOrder.setObjectName("spinBox_BGPolyOrder")
        self.horizontalLayout_3.addWidget(self.spinBox_BGPolyOrder)
        self.verticalLayout_41.addWidget(self.groupBox_31)
        self.tableWidget_BackgroundConstraints = QtWidgets.QTableWidget(self.scrollAreaWidgetContents_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_BackgroundConstraints.sizePolicy().hasHeightForWidth())
        self.tableWidget_BackgroundConstraints.setSizePolicy(sizePolicy)
        self.tableWidget_BackgroundConstraints.setMinimumSize(QtCore.QSize(0, 100))
        self.tableWidget_BackgroundConstraints.setMaximumSize(QtCore.QSize(16777215, 100))
        self.tableWidget_BackgroundConstraints.setObjectName("tableWidget_BackgroundConstraints")
        self.tableWidget_BackgroundConstraints.setColumnCount(0)
        self.tableWidget_BackgroundConstraints.setRowCount(0)
        self.verticalLayout_41.addWidget(self.tableWidget_BackgroundConstraints)
        self.scrollArea_12.setWidget(self.scrollAreaWidgetContents_12)
        self.verticalLayout_13.addWidget(self.scrollArea_12)
        self.tabWidget_PeakFit.addTab(self.tab_PeakFitConfig, "")
        self.verticalLayout_7.addWidget(self.tabWidget_PeakFit)
        self.tabWidget_4.addTab(self.tabWidget_4Page1, "")
        self.tabWidget_4Page2 = QtWidgets.QWidget()
        self.tabWidget_4Page2.setObjectName("tabWidget_4Page2")
        self.verticalLayout_42 = QtWidgets.QVBoxLayout(self.tabWidget_4Page2)
        self.verticalLayout_42.setObjectName("verticalLayout_42")
        self.scrollArea_9 = QtWidgets.QScrollArea(self.tabWidget_4Page2)
        self.scrollArea_9.setWidgetResizable(True)
        self.scrollArea_9.setObjectName("scrollArea_9")
        self.scrollAreaWidgetContents_9 = QtWidgets.QWidget()
        self.scrollAreaWidgetContents_9.setGeometry(QtCore.QRect(0, 0, 225, 352))
        self.scrollAreaWidgetContents_9.setObjectName("scrollAreaWidgetContents_9")
        self.verticalLayout_38 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents_9)
        self.verticalLayout_38.setObjectName("verticalLayout_38")
        self.groupBox_15 = QtWidgets.QGroupBox(self.scrollAreaWidgetContents_9)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_15.sizePolicy().hasHeightForWidth())
        self.groupBox_15.setSizePolicy(sizePolicy)
        self.groupBox_15.setTitle("")
        self.groupBox_15.setFlat(False)
        self.groupBox_15.setObjectName("groupBox_15")
        self.gridLayout_22 = QtWidgets.QGridLayout(self.groupBox_15)
        self.gridLayout_22.setContentsMargins(12, 12, 12, 12)
        self.gridLayout_22.setObjectName("gridLayout_22")
        self.pushButton_PerformUCFit = QtWidgets.QPushButton(self.groupBox_15)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_PerformUCFit.sizePolicy().hasHeightForWidth())
        self.pushButton_PerformUCFit.setSizePolicy(sizePolicy)
        self.pushButton_PerformUCFit.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_PerformUCFit.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.pushButton_PerformUCFit.setFont(font)
        self.pushButton_PerformUCFit.setObjectName("pushButton_PerformUCFit")
        self.gridLayout_22.addWidget(self.pushButton_PerformUCFit, 2, 0, 1, 1)
        self.comboBox_Symmetry = QtWidgets.QComboBox(self.groupBox_15)
        self.comboBox_Symmetry.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_Symmetry.setObjectName("comboBox_Symmetry")
        self.gridLayout_22.addWidget(self.comboBox_Symmetry, 2, 1, 1, 1)
        self.comboBox_PeakFitLabels = QtWidgets.QComboBox(self.groupBox_15)
        self.comboBox_PeakFitLabels.setMinimumSize(QtCore.QSize(0, 25))
        self.comboBox_PeakFitLabels.setObjectName("comboBox_PeakFitLabels")
        self.gridLayout_22.addWidget(self.comboBox_PeakFitLabels, 1, 1, 1, 1)
        self.pushButton_CollectPeakFitResults = QtWidgets.QPushButton(self.groupBox_15)
        self.pushButton_CollectPeakFitResults.setMinimumSize(QtCore.QSize(0, 25))
        self.pushButton_CollectPeakFitResults.setObjectName("pushButton_CollectPeakFitResults")
        self.gridLayout_22.addWidget(self.pushButton_CollectPeakFitResults, 1, 0, 1, 1)
        self.verticalLayout_38.addWidget(self.groupBox_15)
        self.frame_12 = QtWidgets.QFrame(self.scrollAreaWidgetContents_9)
        self.frame_12.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_12.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_12.setObjectName("frame_12")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout(self.frame_12)
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.tableWidget_UnitCell = QtWidgets.QTableWidget(self.frame_12)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableWidget_UnitCell.sizePolicy().hasHeightForWidth())
        self.tableWidget_UnitCell.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.tableWidget_UnitCell.setFont(font)
        self.tableWidget_UnitCell.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.tableWidget_UnitCell.setWordWrap(False)
        self.tableWidget_UnitCell.setColumnCount(0)
        self.tableWidget_UnitCell.setObjectName("tableWidget_UnitCell")
        self.tableWidget_UnitCell.setRowCount(0)
        self.tableWidget_UnitCell.horizontalHeader().setVisible(False)
        self.tableWidget_UnitCell.horizontalHeader().setCascadingSectionResizes(True)
        self.tableWidget_UnitCell.verticalHeader().setVisible(False)
        self.tableWidget_UnitCell.verticalHeader().setCascadingSectionResizes(True)
        self.verticalLayout_22.addWidget(self.tableWidget_UnitCell)
        self.verticalLayout_38.addWidget(self.frame_12)
        self.frame_14 = QtWidgets.QFrame(self.scrollAreaWidgetContents_9)
        self.frame_14.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.frame_14.setFrameShadow(QtWidgets.QFrame.Raised)
        self.frame_14.setObjectName("frame_14")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.frame_14)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.plainTextEdit_UCFitOutput = QtWidgets.QPlainTextEdit(self.frame_14)
        self.plainTextEdit_UCFitOutput.setObjectName("plainTextEdit_UCFitOutput")
        self.verticalLayout_24.addWidget(self.plainTextEdit_UCFitOutput)
        self.verticalLayout_38.addWidget(self.frame_14)
        self.scrollArea_9.setWidget(self.scrollAreaWidgetContents_9)
        self.verticalLayout_42.addWidget(self.scrollArea_9)
        self.tabWidget_4.addTab(self.tabWidget_4Page2, "")
        self.verticalLayout_14.addWidget(self.tabWidget_4)
        self.tabWidget.addTab(self.tab_PkFt, "")
        self.verticalLayout_9.addWidget(self.tabWidget)
        self.verticalLayout_25.addWidget(self.splitter)
        MainWindow.setCentralWidget(self.centralwidget)
        self.mplactionOpen = QtWidgets.QAction(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        self.mplactionOpen.setFont(font)
        self.mplactionOpen.setObjectName("mplactionOpen")
        self.actionClose = QtWidgets.QAction(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        self.actionClose.setFont(font)
        self.actionClose.setObjectName("actionClose")
        self.mplactionSave_background = QtWidgets.QAction(MainWindow)
        self.mplactionSave_background.setObjectName("mplactionSave_background")
        self.mplactionSave_background_subtracted = QtWidgets.QAction(MainWindow)
        self.mplactionSave_background_subtracted.setObjectName("mplactionSave_background_subtracted")
        self.actionSet_range = QtWidgets.QAction(MainWindow)
        self.actionSet_range.setObjectName("actionSet_range")
        self.actionY_Scale = QtWidgets.QAction(MainWindow)
        self.actionY_Scale.setObjectName("actionY_Scale")
        self.mplactionPrint = QtWidgets.QAction(MainWindow)
        self.mplactionPrint.setObjectName("mplactionPrint")
        self.actionBackground_parameters = QtWidgets.QAction(MainWindow)
        self.actionBackground_parameters.setObjectName("actionBackground_parameters")
        self.mplactionNew_JList = QtWidgets.QAction(MainWindow)
        self.mplactionNew_JList.setObjectName("mplactionNew_JList")
        self.mplactionLoad_Jlist = QtWidgets.QAction(MainWindow)
        self.mplactionLoad_Jlist.setObjectName("mplactionLoad_Jlist")
        self.mplactionSave_JList = QtWidgets.QAction(MainWindow)
        self.mplactionSave_JList.setObjectName("mplactionSave_JList")
        self.mplactionEdit_JList = QtWidgets.QAction(MainWindow)
        self.mplactionEdit_JList.setObjectName("mplactionEdit_JList")
        self.mplactionShow_a_JCPDS_card = QtWidgets.QAction(MainWindow)
        self.mplactionShow_a_JCPDS_card.setObjectName("mplactionShow_a_JCPDS_card")
        self.mplactionXray_wavelength = QtWidgets.QAction(MainWindow)
        self.mplactionXray_wavelength.setObjectName("mplactionXray_wavelength")
        self.mplactionShow_Unshow_JList = QtWidgets.QAction(MainWindow)
        self.mplactionShow_Unshow_JList.setObjectName("mplactionShow_Unshow_JList")
        self.mplactionShow_a_JCPDS_file = QtWidgets.QAction(MainWindow)
        self.mplactionShow_a_JCPDS_file.setObjectName("mplactionShow_a_JCPDS_file")
        self.actionCiting_PeakPo = QtWidgets.QAction(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Helvetica")
        self.actionCiting_PeakPo.setFont(font)
        self.actionCiting_PeakPo.setObjectName("actionCiting_PeakPo")
        self.actionShortcut_keys = QtWidgets.QAction(MainWindow)
        self.actionShortcut_keys.setObjectName("actionShortcut_keys")

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(0)
        self.tabWidget_3.setCurrentIndex(0)
        self.comboBox_BasePtnLineThickness.setCurrentIndex(-1)
        self.tabWidget1.setCurrentIndex(0)
        self.tabWidget_5.setCurrentIndex(0)
        self.tabWidget_2.setCurrentIndex(0)
        self.tabWidget_4.setCurrentIndex(0)
        self.tabWidget_PeakFit.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "PeakPo"))
        self.pushButton_S_Zoom.setToolTip(_translate("MainWindow", "Zoom out"))
        self.pushButton_S_Zoom.setText(_translate("MainWindow", "🔎"))
        self.pushButton_S_SaveSession.setToolTip(_translate("MainWindow", "Legacy save button (hidden)"))
        self.pushButton_S_SaveSession.setText(_translate("MainWindow", "💾"))
        self.pushButton_S_PrevBasePtn.setToolTip(_translate("MainWindow", "Previous file"))
        self.pushButton_S_PrevBasePtn.setText(_translate("MainWindow", "←"))
        self.pushButton_AddBasePtn.setToolTip(_translate("MainWindow", "Add current file to waterfall"))
        self.pushButton_AddBasePtn.setText(_translate("MainWindow", "★"))
        self.pushButton_S_NextBasePtn.setToolTip(_translate("MainWindow", "Next file"))
        self.pushButton_S_NextBasePtn.setText(_translate("MainWindow", "→"))
        self.pushButton_S_PIncrease.setToolTip(_translate("MainWindow", "Increase pressure"))
        self.pushButton_S_PIncrease.setText(_translate("MainWindow", "P+"))
        self.pushButton_S_PDecrease.setToolTip(_translate("MainWindow", "Decrease pressure"))
        self.pushButton_S_PDecrease.setText(_translate("MainWindow", "P−"))
        self.pushButton_S_TIncrease.setToolTip(_translate("MainWindow", "Increase temperature"))
        self.pushButton_S_TIncrease.setText(_translate("MainWindow", "T+"))
        self.pushButton_S_RoomT.setToolTip(_translate("MainWindow", "Set temperture to 300 K"))
        self.pushButton_S_RoomT.setText(_translate("MainWindow", "T0"))
        self.pushButton_S_TDecrease.setToolTip(_translate("MainWindow", "Decrease temperature"))
        self.pushButton_S_TDecrease.setText(_translate("MainWindow", "T−"))
        self.pushButton_NewBasePtn.setToolTip(_translate("MainWindow", "Open base spectrum in SPE or CHI"))
        self.pushButton_NewBasePtn.setText(_translate("MainWindow", "Open SPE"))
        self.pushButton_LoadDPP.setToolTip(_translate("MainWindow", "Save session to the -rampo backup folder"))
        self.pushButton_LoadDPP.setText(_translate("MainWindow", "Save"))
        self.checkBox_ShowCake.setToolTip(_translate("MainWindow", "Show cake image"))
        self.checkBox_ShowCake.setText(_translate("MainWindow", "Cake"))
        self.checkBox_BgSub.setToolTip(_translate("MainWindow", "Subtract background from 1D pattern"))
        self.checkBox_BgSub.setText(_translate("MainWindow", "Bg sub"))
        self.checkBox_AutoY.setToolTip(_translate("MainWindow", "Automatic adjustment of y axis range"))
        self.checkBox_AutoY.setText(_translate("MainWindow", "Auto y"))
        self.checkBox_LongCursor.setToolTip(_translate("MainWindow", "Change cursor to a vertical bar"))
        self.checkBox_LongCursor.setText(_translate("MainWindow", "Vert. Cursor"))
        self.groupBox_28.setTitle(_translate("MainWindow", "Navigation"))
        self.pushButton_FirstBasePtn.setToolTip(_translate("MainWindow", "Open the first CHI file"))
        self.pushButton_FirstBasePtn.setText(_translate("MainWindow", "<<"))
        self.pushButton_PrevBasePtn.setToolTip(_translate("MainWindow", "Open previous CHI file"))
        self.pushButton_PrevBasePtn.setText(_translate("MainWindow", "<"))
        self.pushButton_NextBasePtn.setToolTip(_translate("MainWindow", "Open next CHI file"))
        self.pushButton_NextBasePtn.setText(_translate("MainWindow", ">"))
        self.pushButton_LastBasePtn.setToolTip(_translate("MainWindow", "Open the last CHI file"))
        self.pushButton_LastBasePtn.setText(_translate("MainWindow", ">>"))
        self.label_21.setText(_translate("MainWindow", "Step"))
        self.spinBox_FileStep.setToolTip(_translate("MainWindow", "Step for the navigation buttons"))
        self.radioButton_SortbyNme.setToolTip(_translate("MainWindow", "Sort files in current directory by name"))
        self.radioButton_SortbyNme.setText(_translate("MainWindow", "Name"))
        self.radioButton_SortbyTime.setToolTip(_translate("MainWindow", "Sort files in current directory by time stamp"))
        self.radioButton_SortbyTime.setText(_translate("MainWindow", "Time"))
        self.groupBox_3.setTitle(_translate("MainWindow", "Spectrum"))
        self.lineEdit_DiffractionPatternFileName.setToolTip(_translate("MainWindow", "Name and path of base 1D diffraction pattern"))
        self.pushButton_Info.setText(_translate("MainWindow", "Info"))
        self.doubleSpinBox_SetWavelength.setToolTip(_translate("MainWindow", "Excitation laser wavelength (nm)"))
        self.label_XRayEnergy.setText(_translate("MainWindow", "nm"))
        self.pushButton_SetXEat30.setText(_translate("MainWindow", "30"))
        self.pushButton_SetXEat37.setText(_translate("MainWindow", "37"))
        self.pushButton_SetXEat42.setText(_translate("MainWindow", "42"))
        self.groupBox_2.setTitle(_translate("MainWindow", "Session (PARAM)"))
        self.pushButton_SaveDPP.setToolTip(_translate("MainWindow", "Save session to PARAM files"))
        self.pushButton_SaveDPP.setText(_translate("MainWindow", "💾"))
        self.pushButton_OpenBackupInfo.setToolTip(_translate("MainWindow", "Show backup snapshot information"))
        self.pushButton_OpenBackupInfo.setText(_translate("MainWindow", "🕘"))
        self.textEdit_SessionFileName.setToolTip(_translate("MainWindow", "Session file (read-only box, use the buttons)"))
        self.groupBox_36.setTitle(_translate("MainWindow", "Raw image handling"))
        self.checkBox_IgnoreRawDataExistence.setText(_translate("MainWindow", "Ignore raw data absence in the folder"))
        self.tabWidget_3.setTabText(self.tabWidget_3.indexOf(self.tabWidget_3Page1), _translate("MainWindow", "Data"))
        self.pushButton_AboutPeakpo.setToolTip(_translate("MainWindow", "Information on PeakPo"))
        self.pushButton_AboutPeakpo.setText(_translate("MainWindow", "About PeakPo"))
        self.pushButton_Help.setToolTip(_translate("MainWindow", "Help on PeakPo"))
        self.pushButton_Help.setText(_translate("MainWindow", "Help"))
        self.groupBox_34.setTitle(_translate("MainWindow", "Plot control"))
        self.checkBox_JCPDSinCake.setToolTip(_translate("MainWindow", "Show JCPDS in cake image"))
        self.checkBox_JCPDSinCake.setText(_translate("MainWindow", "jcpds, cake"))
        self.checkBox_Intensity.setToolTip(_translate("MainWindow", "Plot JCPDS bar height proportional to intensity"))
        self.checkBox_Intensity.setText(_translate("MainWindow", "jcpd by int."))
        self.checkBox_JCPDSinPattern.setToolTip(_translate("MainWindow", "Show JCPDS in 1D pattern"))
        self.checkBox_JCPDSinPattern.setText(_translate("MainWindow", "jcpds, ptn"))
        self.checkBox_ShowMillerIndices_Cake.setToolTip(_translate("MainWindow", "Show Miller indices in cake"))
        self.checkBox_ShowMillerIndices_Cake.setText(_translate("MainWindow", "hkl, cake"))
        self.checkBox_ShowMillerIndices.setToolTip(_translate("MainWindow", "Show Miller indices in 1D pattern"))
        self.checkBox_ShowMillerIndices.setText(_translate("MainWindow", "hkl, ptn"))
        self.checkBox_ShowCakeLabels.setToolTip(_translate("MainWindow", "Show cake labels"))
        self.checkBox_ShowCakeLabels.setText(_translate("MainWindow", "Cake labels"))
        self.checkBox_ShowWaterfall.setToolTip(_translate("MainWindow", "Show waterfall patterns"))
        self.checkBox_ShowWaterfall.setText(_translate("MainWindow", "Waterfall"))
        self.checkBox_ShowWaterfallLabels.setToolTip(_translate("MainWindow", "Show filenames in waterfall"))
        self.checkBox_ShowWaterfallLabels.setText(_translate("MainWindow", "Waterfall labels"))
        self.groupBox_16.setTitle(_translate("MainWindow", "Plot setup"))
        self.checkBox_NightView.setToolTip(_translate("MainWindow", "Show in black background"))
        self.checkBox_NightView.setText(_translate("MainWindow", "Night, ptn"))
        self.checkBox_WhiteForPeak.setToolTip(_translate("MainWindow", "Make white for peak intensity"))
        self.checkBox_WhiteForPeak.setText(_translate("MainWindow", "Night, cake"))
        self.checkBox_ShowLargePnT.setToolTip(_translate("MainWindow", "Show large pressure label"))
        self.checkBox_ShowLargePnT.setText(_translate("MainWindow", "P label"))
        self.checkBox_ShortPlotTitle.setToolTip(_translate("MainWindow", "Make the title in 1D pattern short"))
        self.checkBox_ShortPlotTitle.setText(_translate("MainWindow", "Short title"))
        self.groupBox_24.setTitle(_translate("MainWindow", "Line thickness"))
        self.label_17.setText(_translate("MainWindow", "Spectrum"))
        self.label_24.setText(_translate("MainWindow", "Bkgn"))
        self.label_25.setText(_translate("MainWindow", "Waterfall"))
        self.label_26.setText(_translate("MainWindow", "Vert. cursor"))
        self.groupBox_17.setTitle(_translate("MainWindow", "Navigation"))
        self.checkBox_NavDPP.setToolTip(_translate("MainWindow", "Navigate dpp files rather than chi files"))
        self.checkBox_NavDPP.setText(_translate("MainWindow", "Navigate for dpp"))
        self.checkBox_AutoGenDPP.setToolTip(_translate("MainWindow", "When chi navigate, create a dpp file for the next chi from the current dpp file"))
        self.checkBox_AutoGenDPP.setText(_translate("MainWindow", "Auto generate dpp during chi navigation"))
        self.checkBox_SaveDPPMove.setToolTip(_translate("MainWindow", "When dpp navigate, save current dpp file before move to the next dpp file."))
        self.checkBox_SaveDPPMove.setText(_translate("MainWindow", "Auto generate dpp during dpp navigation"))
        self.groupBox_22.setTitle(_translate("MainWindow", "Dpp files"))
        self.checkBox_ForceOverwite.setToolTip(_translate("MainWindow", "Overwrite DPP and PPSS with default name"))
        self.checkBox_ForceOverwite.setText(_translate("MainWindow", "Default name for dpp"))
        self.checkBox_IgnoreDirChange.setText(_translate("MainWindow", "Ignore directory change"))
        self.checkBox_AutogenMissing.setText(_translate("MainWindow", "Autogen only for missing"))
        self.groupBox_12.setTitle(_translate("MainWindow", "Disabled legacy session tools"))
        self.pushButton_LoadPPSS.setToolTip(_translate("MainWindow", "Disabled"))
        self.pushButton_LoadPPSS.setText(_translate("MainWindow", "Disabled"))
        self.pushButton_SavePPSS.setToolTip(_translate("MainWindow", "Disabled"))
        self.pushButton_SavePPSS.setText(_translate("MainWindow", "Disabled"))
        self.pushButton_ZipSession.setToolTip(_translate("MainWindow", "Disabled"))
        self.pushButton_ZipSession.setText(_translate("MainWindow", "Disabled"))
        self.pushButton_SaveDPPandPPSS.setToolTip(_translate("MainWindow", "Disabled"))
        self.pushButton_SaveDPPandPPSS.setText(_translate("MainWindow", "Disabled"))
        self.groupBox_10.setTitle(_translate("MainWindow", "Temporary files"))
        self.pushButton_DelTempCake.setToolTip(_translate("MainWindow", "Delete temporary cake files"))
        self.pushButton_DelTempCake.setText(_translate("MainWindow", "Delete temp cake"))
        self.checkBox_UseTempCake.setText(_translate("MainWindow", "Use for cake"))
        self.pushButton_DelTempCHI.setToolTip(_translate("MainWindow", "Delete temporary CHI files"))
        self.pushButton_DelTempCHI.setText(_translate("MainWindow", "Delete temp chi"))
        self.checkBox_UseTempBGSub.setText(_translate("MainWindow", "Use for bgsub"))
        self.tabWidget_3.setTabText(self.tabWidget_3.indexOf(self.tabWidget_3Page2), _translate("MainWindow", "Config"))
        self.pushButton_BackupRestore.setToolTip(_translate("MainWindow", "Restore highlighted backup"))
        self.pushButton_BackupRestore.setText(_translate("MainWindow", "🕘"))
        self.tabWidget_3.setTabText(self.tabWidget_3.indexOf(self.tabWidget_3Page3), _translate("MainWindow", "Backup"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_Main), _translate("MainWindow", "File"))
        self.groupBox.setTitle(_translate("MainWindow", "Pressure (GPa) and Temeprature (K)"))
        self.frame_17.setToolTip(_translate("MainWindow", "Temperature steps"))
        self.doubleSpinBox_Temperature.setToolTip(_translate("MainWindow", "Temperature in kelvins"))
        self.pushButton_RoomT.setToolTip(_translate("MainWindow", "Set temperature to 300 K"))
        self.pushButton_RoomT.setText(_translate("MainWindow", "300 K"))
        self.spinBox_TStep.setToolTip(_translate("MainWindow", "Step size for temperature"))
        self.pushButton_SetTStepTo100.setToolTip(_translate("MainWindow", "Set temperature step size to 100"))
        self.pushButton_SetTStepTo100.setText(_translate("MainWindow", "1e2"))
        self.pushButton_SetTStepTo1000.setToolTip(_translate("MainWindow", "Set temperature step size to 1000"))
        self.pushButton_SetTStepTo1000.setText(_translate("MainWindow", "1e3"))
        self.frame_16.setToolTip(_translate("MainWindow", "Pressure steps"))
        self.doubleSpinBox_Pressure.setToolTip(_translate("MainWindow", "Pressure in GPa"))
        self.pushButton_1bar.setToolTip(_translate("MainWindow", "Set pressure to 1 bar"))
        self.pushButton_1bar.setText(_translate("MainWindow", "1 bar"))
        self.doubleSpinBox_PStep.setToolTip(_translate("MainWindow", "Step size for pressure"))
        self.pushButton_SetPStepTo1.setToolTip(_translate("MainWindow", "Set pressure step size to 1"))
        self.pushButton_SetPStepTo1.setText(_translate("MainWindow", "1"))
        self.pushButton_SetPStepTo10.setToolTip(_translate("MainWindow", "Set pressure step size to 10"))
        self.pushButton_SetPStepTo10.setText(_translate("MainWindow", "10"))
        self.pushButton_AddToJlist.setToolTip(_translate("MainWindow", "Add a JCPDS file to the list"))
        self.pushButton_AddToJlist.setText(_translate("MainWindow", "+"))
        self.pushButton_ViewJCPDS.setToolTip(_translate("MainWindow", "Show calculation result for highlighted JCPDS in the Output tab"))
        self.pushButton_ViewJCPDS.setText(_translate("MainWindow", "Show"))
        self.pushButton_MoveDown.setToolTip(_translate("MainWindow", "Move down highlighted row in the list"))
        self.pushButton_MoveDown.setText(_translate("MainWindow", "↓"))
        self.pushButton_MoveUp.setToolTip(_translate("MainWindow", "Move up highlighted row in the list"))
        self.pushButton_MoveUp.setText(_translate("MainWindow", "↑"))
        self.pushButton_SaveTwkJCPDS.setToolTip(_translate("MainWindow", "Save Twk\'ed JCPDSs for the checked items"))
        self.pushButton_SaveTwkJCPDS.setText(_translate("MainWindow", "Save"))
        self.pushButton_RemoveJCPDS.setToolTip(_translate("MainWindow", "Remove highlighted JCPDS from the list"))
        self.pushButton_RemoveJCPDS.setText(_translate("MainWindow", "−"))
        self.pushButton_savePeakPos.setText(_translate("MainWindow", "Pos"))
        self.pushButton_UpdateJCPDSSteps.setToolTip(_translate("MainWindow", "Update step size for tweak"))
        self.pushButton_UpdateJCPDSSteps.setText(_translate("MainWindow", "Update"))
        self.doubleSpinBox_JCPDSStep.setToolTip(_translate("MainWindow", "Step size of JCPDS tweak"))
        self.pushButton_SetJCPDSStepTo0001.setToolTip(_translate("MainWindow", "Set step size to 0.001"))
        self.pushButton_SetJCPDSStepTo0001.setText(_translate("MainWindow", "1e-3"))
        self.pushButton_SetJCPDSStepTo001.setToolTip(_translate("MainWindow", "Set step size to 0.01"))
        self.pushButton_SetJCPDSStepTo001.setText(_translate("MainWindow", "1e-2"))
        self.pushButton_SetJCPDSStepTo01.setToolTip(_translate("MainWindow", "Set step size to 0.1"))
        self.pushButton_SetJCPDSStepTo01.setText(_translate("MainWindow", "0.1"))
        self.tabWidget1.setTabText(self.tabWidget1.indexOf(self.tabWidgetPage1), _translate("MainWindow", "Data"))
        self.pushButton_ForceUpdatePlot.setToolTip(_translate("MainWindow", "Force update plot"))
        self.pushButton_ForceUpdatePlot.setText(_translate("MainWindow", "Update plot"))
        self.groupBox_18.setTitle(_translate("MainWindow", "JCPDS list source"))
        self.textEdit_Jlist.setToolTip(_translate("MainWindow", "Source file for current JCPDS list"))
        self.groupBox_20.setTitle(_translate("MainWindow", "JCPDS bars"))
        self.label_27.setText(_translate("MainWindow", "Height"))
        self.horizontalSlider_JCPDSBarScale.setToolTip(_translate("MainWindow", "Change height of the JCPDS bars"))
        self.label_28.setText(_translate("MainWindow", "Position"))
        self.horizontalSlider_JCPDSBarPosition.setToolTip(_translate("MainWindow", "Change position of the JCPDS bars"))
        self.groupBox_26.setTitle(_translate("MainWindow", "Setup"))
        self.checkBox_UseJCPDSTable1bar.setToolTip(_translate("MainWindow", "Force to use table d-spacing values in JCPDS for 0 GPa"))
        self.checkBox_UseJCPDSTable1bar.setText(_translate("MainWindow", "Show table value at 1 bar"))
        self.groupBox_13.setTitle(_translate("MainWindow", "Font size"))
        self.label_15.setText(_translate("MainWindow", "PT label"))
        self.label_3.setText(_translate("MainWindow", "Miller indices"))
        self.groupBox_27.setTitle(_translate("MainWindow", "JCPDS Opacity"))
        self.label_30.setText(_translate("MainWindow", "Alpha, cake"))
        self.label_23.setText(_translate("MainWindow", "Thick, cake"))
        self.label_22.setText(_translate("MainWindow", "Thick, ptn"))
        self.label_29.setText(_translate("MainWindow", "Alpha, ptn"))
        self.groupBox_9.setTitle(_translate("MainWindow", "List"))
        self.pushButton_NewJlist.setToolTip(_translate("MainWindow", "Make a new JCPDS list"))
        self.pushButton_NewJlist.setText(_translate("MainWindow", "New"))
        self.pushButton_ImportJlist.setToolTip(_translate("MainWindow", "Import a JCPDS list from a dpp file"))
        self.pushButton_ImportJlist.setText(_translate("MainWindow", "Import"))
        self.pushButton_SaveJlist.setToolTip(_translate("MainWindow", "Save current JCPDS list to a dpp file"))
        self.pushButton_SaveJlist.setText(_translate("MainWindow", "Save"))
        self.pushButton_ExportXLS.setToolTip(_translate("MainWindow", "Save JCPDSs to an excel file"))
        self.pushButton_ExportXLS.setText(_translate("MainWindow", "XLS"))
        self.tabWidget1.setTabText(self.tabWidget1.indexOf(self.tabWidgetPage2), _translate("MainWindow", "Config"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_JCPDSList2), _translate("MainWindow", "JCPDS"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_Plot), _translate("MainWindow", "Plot"))
        self.pushButton_UpdateBackground.setToolTip(_translate("MainWindow", "Apply current process and smoothing parameters"))
        self.pushButton_UpdateBackground.setText(_translate("MainWindow", "Update"))
        self.groupBox_4.setTitle(_translate("MainWindow", "Range for background fit"))
        self.label_2.setText(_translate("MainWindow", "Minimum two theta"))
        self.label.setText(_translate("MainWindow", "Maximum two theta"))
        self.doubleSpinBox_Background_ROI_max.setToolTip(_translate("MainWindow", "Max two theta angle for background fit"))
        self.doubleSpinBox_Background_ROI_min.setToolTip(_translate("MainWindow", "Min two theta angle for background fit"))
        self.groupBox_7.setTitle(_translate("MainWindow", "Parameters"))
        self.spinBox_BGParam2.setToolTip(_translate("MainWindow", "Number of iterations"))
        self.spinBox_BGParam1.setToolTip(_translate("MainWindow", "Number of order for fit function"))
        self.label_5.setText(_translate("MainWindow", "N Iteration (20):"))
        self.spinBox_BGParam0.setToolTip(_translate("MainWindow", "Number of points for smoothing"))
        self.label_4.setText(_translate("MainWindow", "N Points (20):"))
        self.label_6.setText(_translate("MainWindow", "N Order (10):"))
        self.pushButton_SaveBgSubCHI.setToolTip(_translate("MainWindow", "Save background subtracted 1D pattern"))
        self.pushButton_SaveBgSubCHI.setText(_translate("MainWindow", "Save BgSub.CHI"))
        self.tabWidget_5.setTabText(self.tabWidget_5.indexOf(self.tabWidget_5Page1), _translate("MainWindow", "Process"))
        self.pushButton_ApplyWaterfallChange.setToolTip(_translate("MainWindow", "Force update graph"))
        self.pushButton_ApplyWaterfallChange.setText(_translate("MainWindow", "Update plot"))
        self.checkBox_SetToBasePtnLambda.setToolTip(_translate("MainWindow", "Convert two theta angles of waterfall patterns to match the wavelength of base pattern"))
        self.checkBox_SetToBasePtnLambda.setText(_translate("MainWindow", "Convert to base ptn wavelength"))
        self.checkBox_IntNorm.setToolTip(_translate("MainWindow", "Normalize intensities of waterfall pattern with respect to their max. intensities"))
        self.checkBox_IntNorm.setText(_translate("MainWindow", "Normalize intensity for same scale"))
        self.label_18.setText(_translate("MainWindow", "Waterfall gap"))
        self.horizontalSlider_WaterfallGaps.setToolTip(_translate("MainWindow", "Change size of vertical gaps between waterfall patterns"))
        self.pushButton_AddPatterns.setToolTip(_translate("MainWindow", "Add CHI files to waterfall list"))
        self.pushButton_AddPatterns.setText(_translate("MainWindow", "+"))
        self.pushButton_DownPattern.setToolTip(_translate("MainWindow", "Move down highlighted pattern in the waterfall list"))
        self.pushButton_DownPattern.setText(_translate("MainWindow", "↓"))
        self.pushButton_UpPattern.setToolTip(_translate("MainWindow", "Move up highlighted pattern in the waterfall list"))
        self.pushButton_UpPattern.setText(_translate("MainWindow", "↑"))
        self.pushButton_RemovePatterns.setToolTip(_translate("MainWindow", "Remove highlighted patterns in the waterfall list"))
        self.pushButton_RemovePatterns.setText(_translate("MainWindow", "−"))
        self.pushButton_MakeBasePtn.setToolTip(_translate("MainWindow", "Set highlighted pattern in the waterfall list as a base pattern"))
        self.pushButton_MakeBasePtn.setText(_translate("MainWindow", "Set base"))
        self.pushButton_CheckAllWaterfall.setToolTip(_translate("MainWindow", "Show all the patterns in waterfall list in graph"))
        self.pushButton_CheckAllWaterfall.setText(_translate("MainWindow", "✓"))
        self.pushButton_CleanPatterns.setToolTip(_translate("MainWindow", "Clean up waterfall list"))
        self.pushButton_CleanPatterns.setText(_translate("MainWindow", "Clear"))
        self.pushButton_UncheckAllWaterfall.setToolTip(_translate("MainWindow", "Hide all the patterns in waterfall list from graph"))
        self.pushButton_UncheckAllWaterfall.setText(_translate("MainWindow", "☐"))
        self.tabWidget_5.setTabText(self.tabWidget_5.indexOf(self.tabWidget_5Page2), _translate("MainWindow", "Waterfall"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_Bkgn), _translate("MainWindow", "Spectrum"))
        self.pushButton_ApplyCakeView.setToolTip(_translate("MainWindow", "Force update plot"))
        self.pushButton_ApplyCakeView.setText(_translate("MainWindow", "Update cake"))
        self.groupBox_29.setTitle(_translate("MainWindow", "Gray scale"))
        self.spinBox_MaxCakeScale.setToolTip(_translate("MainWindow", "Max value of the gray scale"))
        self.pushButton_ResetCakeScale.setToolTip(_translate("MainWindow", "Reset to the max value of the scale to the max value of image"))
        self.pushButton_ResetCakeScale.setText(_translate("MainWindow", "Reset Scale"))
        self.label_8.setText(_translate("MainWindow", "Min"))
        self.horizontalSlider_VMin.setToolTip(_translate("MainWindow", "Change min value of gray scale"))
        self.label_9.setText(_translate("MainWindow", "Max"))
        self.horizontalSlider_VMax.setToolTip(_translate("MainWindow", "Change max value of gray scale"))
        self.label_19.setText(_translate("MainWindow", "Scale"))
        self.horizontalSlider_MaxScaleBars.setToolTip(_translate("MainWindow", "Coarse adjustment of the gray scale"))
        self.label_20.setText(_translate("MainWindow", "Vertical size"))
        self.horizontalSlider_CakeAxisSize.setToolTip(_translate("MainWindow", "Vertical size of cake image"))
        self.label_7.setText(_translate("MainWindow", "Azimuthal angle shift"))
        self.spinBox_AziShift.setToolTip(_translate("MainWindow", "Azimuthal angle shift in degrees"))
        self.lineEdit_PONI.setToolTip(_translate("MainWindow", "PONI file name and location"))
        self.pushButton_GetPONI.setToolTip(_translate("MainWindow", "Open a PONI file"))
        self.pushButton_GetPONI.setText(_translate("MainWindow", "📂"))
        self.label_32.setText(_translate("MainWindow", "PONI"))
        self.label_33.setText(_translate("MainWindow", "Image file"))
        self.textEdit_DiffractionImageFilename.setToolTip(_translate("MainWindow", "Diffraction image files (e.g., *.tif) should be in the same folder as CHI"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tabWidget_2Page1), _translate("MainWindow", "Config"))
        self.label_34.setText(_translate("MainWindow", "Mask"))
        self.label_11.setText(_translate("MainWindow", "Min"))
        self.spinBox_MaskMin.setToolTip(_translate("MainWindow", "Values lower than this will be masked"))
        self.label_10.setText(_translate("MainWindow", "Max"))
        self.spinBox_MaskMax.setToolTip(_translate("MainWindow", "Values higher than this will be masked"))
        self.pushButton_MaskReset.setText(_translate("MainWindow", "Reset"))
        self.pushButton_ApplyMask.setToolTip(_translate("MainWindow", "Apply mask out intensities"))
        self.pushButton_ApplyMask.setText(_translate("MainWindow", "Apply"))
        self.pushButton_AddAzi.setToolTip(_translate("MainWindow", "Add a marker from currently plotted cake range"))
        self.pushButton_AddAzi.setText(_translate("MainWindow", "Add"))
        self.pushButton_ClearAziList.setToolTip(_translate("MainWindow", "Clear marker list"))
        self.pushButton_ClearAziList.setText(_translate("MainWindow", "Clear"))
        self.pushButton_LoadCakeMarkerFile.setToolTip(_translate("MainWindow", "Load a marker file"))
        self.pushButton_LoadCakeMarkerFile.setText(_translate("MainWindow", "Load"))
        self.pushButton_RemoveAzi.setToolTip(_translate("MainWindow", "Remove highlighted markers from the list"))
        self.pushButton_RemoveAzi.setText(_translate("MainWindow", "Remove"))
        self.pushButton_InvertCakeBoxes.setToolTip(_translate("MainWindow", "Invert marker ranges"))
        self.pushButton_InvertCakeBoxes.setText(_translate("MainWindow", "Invert"))
        self.pushButton_SaveCakeMarkerFile.setToolTip(_translate("MainWindow", "Save list to a marker file"))
        self.pushButton_SaveCakeMarkerFile.setText(_translate("MainWindow", "Save"))
        self.pushButton_IntegrateCake.setToolTip(_translate("MainWindow", "Integrate for ranges in the list"))
        self.pushButton_IntegrateCake.setText(_translate("MainWindow", "Integrate"))
        self.pushButton_HighlightSelectedMarker.setToolTip(_translate("MainWindow", "Highlight selected marker in the list"))
        self.pushButton_HighlightSelectedMarker.setText(_translate("MainWindow", "Highlight"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tabWidget_2Page2), _translate("MainWindow", "Integration"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_Cake1), _translate("MainWindow", "Cake"))
        self.pushButton_PkFtSectionRemove.setToolTip(_translate("MainWindow", "Remove highlighted section"))
        self.pushButton_PkFtSectionRemove.setText(_translate("MainWindow", "Remove"))
        self.pushButton_PkFtSectionSetToCurrent.setToolTip(_translate("MainWindow", "Set highlighted section as current for fit or plot"))
        self.pushButton_PkFtSectionSetToCurrent.setText(_translate("MainWindow", "Set to current"))
        self.pushButton_PlotSelectedPkFtResults.setToolTip(_translate("MainWindow", "Plot highlighted fit sections in GSAS style"))
        self.pushButton_PlotSelectedPkFtResults.setText(_translate("MainWindow", "GSAS style"))
        self.pushButton_PkFtSectionClear.setText(_translate("MainWindow", "Clear"))
        self.pushButton_PkFtSectionImport.setToolTip(_translate("MainWindow", "Import peak fitting results from dpp"))
        self.pushButton_PkFtSectionImport.setText(_translate("MainWindow", "Import"))
        self.pushButton_PkFtSectionSavetoXLS.setToolTip(_translate("MainWindow", "Save all fitting results in an excel file"))
        self.pushButton_PkFtSectionSavetoXLS.setText(_translate("MainWindow", "Save XLS"))
        self.tabWidget_PeakFit.setTabText(self.tabWidget_PeakFit.indexOf(self.tab_PeakFitSection), _translate("MainWindow", "Sections"))
        self.groupBox_35.setTitle(_translate("MainWindow", "Section"))
        self.pushButton_ConductFitting.setToolTip(_translate("MainWindow", "Conduct fitting"))
        self.pushButton_ConductFitting.setText(_translate("MainWindow", "Fit"))
        self.pushButton_SetFitSection.setToolTip(_translate("MainWindow", "Set current view as a fitting range"))
        self.pushButton_SetFitSection.setText(_translate("MainWindow", "Set"))
        self.pushButton_ZoomToSection.setToolTip(_translate("MainWindow", "Zome back to the current fit section"))
        self.pushButton_ZoomToSection.setText(_translate("MainWindow", "Zoom "))
        self.pushButton_PkSave.setToolTip(_translate("MainWindow", "Save current fitting results to the sections tab"))
        self.pushButton_PkSave.setText(_translate("MainWindow", "Save"))
        self.pushButton_ClearSection.setToolTip(_translate("MainWindow", "Clear current fitting result"))
        self.pushButton_ClearSection.setText(_translate("MainWindow", "Clear"))
        self.groupBox_32.setTitle(_translate("MainWindow", "Add/Remove peaks"))
        self.pushButton_AddRemoveFromMouse.setToolTip(_translate("MainWindow", "Get starting peak positions from mouse click"))
        self.pushButton_AddRemoveFromMouse.setText(_translate("MainWindow", "From mouse"))
        self.label_16.setText(_translate("MainWindow", "Min. Intensity"))
        self.pushButton_AddRemoveFromJlist.setToolTip(_translate("MainWindow", "Recieve starting peak position values from JCPDS"))
        self.pushButton_AddRemoveFromJlist.setText(_translate("MainWindow", "From jlist"))
        self.tabWidget_PeakFit.setTabText(self.tabWidget_PeakFit.indexOf(self.tab_PeakFitPeaks), _translate("MainWindow", "Peaks"))
        self.groupBox_25.setTitle(_translate("MainWindow", "Peak"))
        self.label_13.setText(_translate("MainWindow", "Initial FWHM (50)"))
        self.label_31.setText(_translate("MainWindow", "Max FWHM (200)"))
        self.label_12.setText(_translate("MainWindow", "Center range (50)"))
        self.groupBox_31.setTitle(_translate("MainWindow", "Background"))
        self.label_14.setText(_translate("MainWindow", "Order for poly. (0)"))
        self.tabWidget_PeakFit.setTabText(self.tabWidget_PeakFit.indexOf(self.tab_PeakFitConfig), _translate("MainWindow", "Config"))
        self.tabWidget_4.setTabText(self.tabWidget_4.indexOf(self.tabWidget_4Page1), _translate("MainWindow", "Pattern"))
        self.pushButton_PerformUCFit.setToolTip(_translate("MainWindow", "Remove highlighted UCFit item from the UCFit list"))
        self.pushButton_PerformUCFit.setText(_translate("MainWindow", "Fit"))
        self.comboBox_Symmetry.setToolTip(_translate("MainWindow", "Crystal system for unit cell fitting"))
        self.comboBox_PeakFitLabels.setToolTip(_translate("MainWindow", "Phase labels from peak fitting"))
        self.pushButton_CollectPeakFitResults.setToolTip(_translate("MainWindow", "Collect peak fitting results and update the phase combo box"))
        self.pushButton_CollectPeakFitResults.setText(_translate("MainWindow", "Collect"))
        self.tabWidget_4.setTabText(self.tabWidget_4.indexOf(self.tabWidget_4Page2), _translate("MainWindow", "Unit Cell"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_PkFt), _translate("MainWindow", "Fits"))
        self.mplactionOpen.setText(_translate("MainWindow", "Open CHI file"))
        self.actionClose.setText(_translate("MainWindow", "Close"))
        self.mplactionSave_background.setText(_translate("MainWindow", "Save background"))
        self.mplactionSave_background_subtracted.setText(_translate("MainWindow", "Save background subtracted"))
        self.actionSet_range.setText(_translate("MainWindow", "Set range"))
        self.actionY_Scale.setText(_translate("MainWindow", "Y Scale (Lin/Log)"))
        self.mplactionPrint.setText(_translate("MainWindow", "Print"))
        self.actionBackground_parameters.setText(_translate("MainWindow", "Background parameters"))
        self.mplactionNew_JList.setText(_translate("MainWindow", "New JList"))
        self.mplactionLoad_Jlist.setText(_translate("MainWindow", "Load JList"))
        self.mplactionSave_JList.setText(_translate("MainWindow", "Save JList"))
        self.mplactionEdit_JList.setText(_translate("MainWindow", "Edit JList"))
        self.mplactionShow_a_JCPDS_card.setText(_translate("MainWindow", "Show a JCPDS card"))
        self.mplactionXray_wavelength.setText(_translate("MainWindow", "X-ray wavelength"))
        self.mplactionShow_Unshow_JList.setText(_translate("MainWindow", "Show/Unshow JList"))
        self.mplactionShow_a_JCPDS_file.setText(_translate("MainWindow", "Show a JCPDS file"))
        self.actionCiting_PeakPo.setText(_translate("MainWindow", "Citing PeakPo"))
        self.actionShortcut_keys.setText(_translate("MainWindow", "Shortcut keys"))
from .mplwidget import MplWidget
